from typing import Any, Final

MAJOR_VERSION: Final[int]
MINOR_VERSION: Final[int]
PATCH_VERSION: Final[str]
__short_version__: Final[Any]
__version__: Final[Any]
REQUIRED_PYTHON_VER: Final[tuple[int, int, int]]
REQUIRED_NEXT_PYTHON_VER: Final[tuple[int, int, int]]
REQUIRED_NEXT_PYTHON_DATE: Final[str]
PLATFORM_FORMAT: Final[str]
MATCH_ALL: Final[str]
ENTITY_MATCH_NONE: Final[str]
ENTITY_MATCH_ALL: Final[str]
DEVICE_DEFAULT_NAME: Final[str]
MAX_LENGTH_EVENT_EVENT_TYPE: Final[int]
MAX_LENGTH_EVENT_ORIGIN: Final[int]
MAX_LENGTH_EVENT_CONTEXT_ID: Final[int]
MAX_LENGTH_STATE_DOMAIN: Final[int]
MAX_LENGTH_STATE_ENTITY_ID: Final[int]
MAX_LENGTH_STATE_STATE: Final[int]
SUN_EVENT_SUNSET: Final[str]
SUN_EVENT_SUNRISE: Final[str]
CONF_ABOVE: Final[str]
CONF_ACCESS_TOKEN: Final[str]
CONF_ADDRESS: Final[str]
CONF_AFTER: Final[str]
CONF_ALIAS: Final[str]
CONF_ALLOWLIST_EXTERNAL_URLS: Final[str]
CONF_API_KEY: Final[str]
CONF_API_TOKEN: Final[str]
CONF_API_VERSION: Final[str]
CONF_ARMING_TIME: Final[str]
CONF_AT: Final[str]
CONF_ATTRIBUTE: Final[str]
CONF_AUTH_MFA_MODULES: Final[str]
CONF_AUTH_PROVIDERS: Final[str]
CONF_AUTHENTICATION: Final[str]
CONF_BASE: Final[str]
CONF_BEFORE: Final[str]
CONF_BELOW: Final[str]
CONF_BINARY_SENSORS: Final[str]
CONF_BRIGHTNESS: Final[str]
CONF_BROADCAST_ADDRESS: Final[str]
CONF_BROADCAST_PORT: Final[str]
CONF_CHOOSE: Final[str]
CONF_CLIENT_ID: Final[str]
CONF_CLIENT_SECRET: Final[str]
CONF_CODE: Final[str]
CONF_COLOR_TEMP: Final[str]
CONF_COMMAND: Final[str]
CONF_COMMAND_CLOSE: Final[str]
CONF_COMMAND_OFF: Final[str]
CONF_COMMAND_ON: Final[str]
CONF_COMMAND_OPEN: Final[str]
CONF_COMMAND_STATE: Final[str]
CONF_COMMAND_STOP: Final[str]
CONF_CONDITION: Final[str]
CONF_CONDITIONS: Final[str]
CONF_CONTINUE_ON_TIMEOUT: Final[str]
CONF_COUNT: Final[str]
CONF_COVERS: Final[str]
CONF_CURRENCY: Final[str]
CONF_CUSTOMIZE: Final[str]
CONF_CUSTOMIZE_DOMAIN: Final[str]
CONF_CUSTOMIZE_GLOB: Final[str]
CONF_DEFAULT: Final[str]
CONF_DELAY: Final[str]
CONF_DELAY_TIME: Final[str]
CONF_DESCRIPTION: Final[str]
CONF_DEVICE: Final[str]
CONF_DEVICES: Final[str]
CONF_DEVICE_CLASS: Final[str]
CONF_DEVICE_ID: Final[str]
CONF_DISARM_AFTER_TRIGGER: Final[str]
CONF_DISCOVERY: Final[str]
CONF_DISKS: Final[str]
CONF_DISPLAY_CURRENCY: Final[str]
CONF_DISPLAY_OPTIONS: Final[str]
CONF_DOMAIN: Final[str]
CONF_DOMAINS: Final[str]
CONF_EFFECT: Final[str]
CONF_ELEVATION: Final[str]
CONF_EMAIL: Final[str]
CONF_ENTITIES: Final[str]
CONF_ENTITY_ID: Final[str]
CONF_ENTITY_NAMESPACE: Final[str]
CONF_ENTITY_PICTURE_TEMPLATE: Final[str]
CONF_EVENT: Final[str]
CONF_EVENT_DATA: Final[str]
CONF_EVENT_DATA_TEMPLATE: Final[str]
CONF_EXCLUDE: Final[str]
CONF_EXTERNAL_URL: Final[str]
CONF_FILENAME: Final[str]
CONF_FILE_PATH: Final[str]
CONF_FOR: Final[str]
CONF_FORCE_UPDATE: Final[str]
CONF_FRIENDLY_NAME: Final[str]
CONF_FRIENDLY_NAME_TEMPLATE: Final[str]
CONF_HEADERS: Final[str]
CONF_HOST: Final[str]
CONF_HOSTS: Final[str]
CONF_HS: Final[str]
CONF_ICON: Final[str]
CONF_ICON_TEMPLATE: Final[str]
CONF_ID: Final[str]
CONF_INCLUDE: Final[str]
CONF_INTERNAL_URL: Final[str]
CONF_IP_ADDRESS: Final[str]
CONF_LATITUDE: Final[str]
CONF_LEGACY_TEMPLATES: Final[str]
CONF_LIGHTS: Final[str]
CONF_LONGITUDE: Final[str]
CONF_MAC: Final[str]
CONF_MAXIMUM: Final[str]
CONF_MEDIA_DIRS: Final[str]
CONF_METHOD: Final[str]
CONF_MINIMUM: Final[str]
CONF_MODE: Final[str]
CONF_MONITORED_CONDITIONS: Final[str]
CONF_MONITORED_VARIABLES: Final[str]
CONF_NAME: Final[str]
CONF_OFFSET: Final[str]
CONF_OPTIMISTIC: Final[str]
CONF_PACKAGES: Final[str]
CONF_PARAMS: Final[str]
CONF_PASSWORD: Final[str]
CONF_PATH: Final[str]
CONF_PAYLOAD: Final[str]
CONF_PAYLOAD_OFF: Final[str]
CONF_PAYLOAD_ON: Final[str]
CONF_PENDING_TIME: Final[str]
CONF_PIN: Final[str]
CONF_PLATFORM: Final[str]
CONF_PORT: Final[str]
CONF_PREFIX: Final[str]
CONF_PROFILE_NAME: Final[str]
CONF_PROTOCOL: Final[str]
CONF_PROXY_SSL: Final[str]
CONF_QUOTE: Final[str]
CONF_RADIUS: Final[str]
CONF_RECIPIENT: Final[str]
CONF_REGION: Final[str]
CONF_REPEAT: Final[str]
CONF_RESOURCE: Final[str]
CONF_RESOURCES: Final[str]
CONF_RESOURCE_TEMPLATE: Final[str]
CONF_RGB: Final[str]
CONF_ROOM: Final[str]
CONF_SCAN_INTERVAL: Final[str]
CONF_SCENE: Final[str]
CONF_SELECTOR: Final[str]
CONF_SENDER: Final[str]
CONF_SENSORS: Final[str]
CONF_SENSOR_TYPE: Final[str]
CONF_SEQUENCE: Final[str]
CONF_SERVICE: Final[str]
CONF_SERVICE_DATA: Final[str]
CONF_SERVICE_TEMPLATE: Final[str]
CONF_SHOW_ON_MAP: Final[str]
CONF_SLAVE: Final[str]
CONF_SOURCE: Final[str]
CONF_SSL: Final[str]
CONF_STATE: Final[str]
CONF_STATE_TEMPLATE: Final[str]
CONF_STRUCTURE: Final[str]
CONF_SWITCHES: Final[str]
CONF_TARGET: Final[str]
CONF_TEMPERATURE_UNIT: Final[str]
CONF_TIMEOUT: Final[str]
CONF_TIME_ZONE: Final[str]
CONF_TOKEN: Final[str]
CONF_TRIGGER_TIME: Final[str]
CONF_TTL: Final[str]
CONF_TYPE: Final[str]
CONF_UNIQUE_ID: Final[str]
CONF_UNIT_OF_MEASUREMENT: Final[str]
CONF_UNIT_SYSTEM: Final[str]
CONF_UNTIL: Final[str]
CONF_URL: Final[str]
CONF_USERNAME: Final[str]
CONF_VALUE_TEMPLATE: Final[str]
CONF_VARIABLES: Final[str]
CONF_VERIFY_SSL: Final[str]
CONF_WAIT_FOR_TRIGGER: Final[str]
CONF_WAIT_TEMPLATE: Final[str]
CONF_WEBHOOK_ID: Final[str]
CONF_WEEKDAY: Final[str]
CONF_WHILE: Final[str]
CONF_WHITELIST: Final[str]
CONF_ALLOWLIST_EXTERNAL_DIRS: Final[str]
LEGACY_CONF_WHITELIST_EXTERNAL_DIRS: Final[str]
CONF_WHITE_VALUE: Final[str]
CONF_XY: Final[str]
CONF_ZONE: Final[str]
EVENT_CALL_SERVICE: Final[str]
EVENT_COMPONENT_LOADED: Final[str]
EVENT_CORE_CONFIG_UPDATE: Final[str]
EVENT_HOMEASSISTANT_CLOSE: Final[str]
EVENT_HOMEASSISTANT_START: Final[str]
EVENT_HOMEASSISTANT_STARTED: Final[str]
EVENT_HOMEASSISTANT_STOP: Final[str]
EVENT_HOMEASSISTANT_FINAL_WRITE: Final[str]
EVENT_LOGBOOK_ENTRY: Final[str]
EVENT_SERVICE_REGISTERED: Final[str]
EVENT_SERVICE_REMOVED: Final[str]
EVENT_STATE_CHANGED: Final[str]
EVENT_THEMES_UPDATED: Final[str]
EVENT_TIMER_OUT_OF_SYNC: Final[str]
EVENT_TIME_CHANGED: Final[str]
DEVICE_CLASS_BATTERY: Final[str]
DEVICE_CLASS_CO: Final[str]
DEVICE_CLASS_CO2: Final[str]
DEVICE_CLASS_CURRENT: Final[str]
DEVICE_CLASS_ENERGY: Final[str]
DEVICE_CLASS_HUMIDITY: Final[str]
DEVICE_CLASS_ILLUMINANCE: Final[str]
DEVICE_CLASS_MONETARY: Final[str]
DEVICE_CLASS_POWER_FACTOR: Final[str]
DEVICE_CLASS_POWER: Final[str]
DEVICE_CLASS_PRESSURE: Final[str]
DEVICE_CLASS_SIGNAL_STRENGTH: Final[str]
DEVICE_CLASS_TEMPERATURE: Final[str]
DEVICE_CLASS_TIMESTAMP: Final[str]
DEVICE_CLASS_VOLTAGE: Final[str]
STATE_ON: Final[str]
STATE_OFF: Final[str]
STATE_HOME: Final[str]
STATE_NOT_HOME: Final[str]
STATE_UNKNOWN: Final[str]
STATE_OPEN: Final[str]
STATE_OPENING: Final[str]
STATE_CLOSED: Final[str]
STATE_CLOSING: Final[str]
STATE_PLAYING: Final[str]
STATE_PAUSED: Final[str]
STATE_IDLE: Final[str]
STATE_STANDBY: Final[str]
STATE_ALARM_DISARMED: Final[str]
STATE_ALARM_ARMED_HOME: Final[str]
STATE_ALARM_ARMED_AWAY: Final[str]
STATE_ALARM_ARMED_NIGHT: Final[str]
STATE_ALARM_ARMED_VACATION: Final[str]
STATE_ALARM_ARMED_CUSTOM_BYPASS: Final[str]
STATE_ALARM_PENDING: Final[str]
STATE_ALARM_ARMING: Final[str]
STATE_ALARM_DISARMING: Final[str]
STATE_ALARM_TRIGGERED: Final[str]
STATE_LOCKED: Final[str]
STATE_UNLOCKED: Final[str]
STATE_LOCKING: Final[str]
STATE_UNLOCKING: Final[str]
STATE_JAMMED: Final[str]
STATE_UNAVAILABLE: Final[str]
STATE_OK: Final[str]
STATE_PROBLEM: Final[str]
ATTR_ATTRIBUTION: Final[str]
ATTR_CREDENTIALS: Final[str]
ATTR_NOW: Final[str]
ATTR_DATE: Final[str]
ATTR_TIME: Final[str]
ATTR_SECONDS: Final[str]
ATTR_DOMAIN: Final[str]
ATTR_SERVICE: Final[str]
ATTR_SERVICE_DATA: Final[str]
ATTR_ID: Final[str]
ATTR_NAME: Final[str]
ATTR_ENTITY_ID: Final[str]
ATTR_AREA_ID: Final[str]
ATTR_DEVICE_ID: Final[str]
ATTR_FRIENDLY_NAME: Final[str]
ATTR_ENTITY_PICTURE: Final[str]
ATTR_IDENTIFIERS: Final[str]
ATTR_ICON: Final[str]
ATTR_UNIT_OF_MEASUREMENT: Final[str]
CONF_UNIT_SYSTEM_METRIC: Final[str]
CONF_UNIT_SYSTEM_IMPERIAL: Final[str]
ATTR_VOLTAGE: Final[str]
ATTR_LOCATION: Final[str]
ATTR_MODE: Final[str]
ATTR_MANUFACTURER: Final[str]
ATTR_MODEL: Final[str]
ATTR_SW_VERSION: Final[str]
ATTR_BATTERY_CHARGING: Final[str]
ATTR_BATTERY_LEVEL: Final[str]
ATTR_WAKEUP: Final[str]
ATTR_CODE: Final[str]
ATTR_CODE_FORMAT: Final[str]
ATTR_COMMAND: Final[str]
ATTR_ARMED: Final[str]
ATTR_LOCKED: Final[str]
ATTR_TRIPPED: Final[str]
ATTR_LAST_TRIP_TIME: Final[str]
ATTR_HIDDEN: Final[str]
ATTR_LATITUDE: Final[str]
ATTR_LONGITUDE: Final[str]
ATTR_GPS_ACCURACY: Final[str]
ATTR_ASSUMED_STATE: Final[str]
ATTR_STATE: Final[str]
ATTR_EDITABLE: Final[str]
ATTR_OPTION: Final[str]
ATTR_RESTORED: Final[str]
ATTR_SUPPORTED_FEATURES: Final[str]
ATTR_DEVICE_CLASS: Final[str]
ATTR_TEMPERATURE: Final[str]
POWER_WATT: Final[str]
POWER_KILO_WATT: Final[str]
POWER_VOLT_AMPERE: Final[str]
ENERGY_WATT_HOUR: Final[str]
ENERGY_KILO_WATT_HOUR: Final[str]
ELECTRIC_CURRENT_MILLIAMPERE: Final[str]
ELECTRIC_CURRENT_AMPERE: Final[str]
ELECTRIC_POTENTIAL_MILLIVOLT: Final[str]
ELECTRIC_POTENTIAL_VOLT: Final[str]
DEGREE: Final[str]
CURRENCY_EURO: Final[str]
CURRENCY_DOLLAR: Final[str]
CURRENCY_CENT: Final[str]
TEMP_CELSIUS: Final[str]
TEMP_FAHRENHEIT: Final[str]
TEMP_KELVIN: Final[str]
TIME_MICROSECONDS: Final[str]
TIME_MILLISECONDS: Final[str]
TIME_SECONDS: Final[str]
TIME_MINUTES: Final[str]
TIME_HOURS: Final[str]
TIME_DAYS: Final[str]
TIME_WEEKS: Final[str]
TIME_MONTHS: Final[str]
TIME_YEARS: Final[str]
LENGTH_MILLIMETERS: Final[str]
LENGTH_CENTIMETERS: Final[str]
LENGTH_METERS: Final[str]
LENGTH_KILOMETERS: Final[str]
LENGTH_INCHES: Final[str]
LENGTH_FEET: Final[str]
LENGTH_YARD: Final[str]
LENGTH_MILES: Final[str]
FREQUENCY_HERTZ: Final[str]
FREQUENCY_MEGAHERTZ: Final[str]
FREQUENCY_GIGAHERTZ: Final[str]
PRESSURE_PA: Final[str]
PRESSURE_HPA: Final[str]
PRESSURE_BAR: Final[str]
PRESSURE_MBAR: Final[str]
PRESSURE_INHG: Final[str]
PRESSURE_PSI: Final[str]
SOUND_PRESSURE_DB: Final[str]
SOUND_PRESSURE_WEIGHTED_DBA: Final[str]
VOLUME_LITERS: Final[str]
VOLUME_MILLILITERS: Final[str]
VOLUME_CUBIC_METERS: Final[str]
VOLUME_CUBIC_FEET: Final[str]
VOLUME_GALLONS: Final[str]
VOLUME_FLUID_OUNCE: Final[str]
VOLUME_FLOW_RATE_CUBIC_METERS_PER_HOUR: Final[str]
VOLUME_FLOW_RATE_CUBIC_FEET_PER_MINUTE: Final[str]
AREA_SQUARE_METERS: Final[str]
MASS_GRAMS: Final[str]
MASS_KILOGRAMS: Final[str]
MASS_MILLIGRAMS: Final[str]
MASS_MICROGRAMS: Final[str]
MASS_OUNCES: Final[str]
MASS_POUNDS: Final[str]
CONDUCTIVITY: Final[str]
LIGHT_LUX: Final[str]
UV_INDEX: Final[str]
PERCENTAGE: Final[str]
IRRADIATION_WATTS_PER_SQUARE_METER: Final[str]
IRRADIATION_BTUS_PER_HOUR_SQUARE_FOOT: Final[str]
PRECIPITATION_MILLIMETERS_PER_HOUR: Final[str]
PRECIPITATION_INCHES: Final[str]
PRECIPITATION_INCHES_PER_HOUR: Final[str]
CONCENTRATION_MICROGRAMS_PER_CUBIC_METER: Final[str]
CONCENTRATION_MILLIGRAMS_PER_CUBIC_METER: Final[str]
CONCENTRATION_MICROGRAMS_PER_CUBIC_FOOT: Final[str]
CONCENTRATION_PARTS_PER_CUBIC_METER: Final[str]
CONCENTRATION_PARTS_PER_MILLION: Final[str]
CONCENTRATION_PARTS_PER_BILLION: Final[str]
SPEED_MILLIMETERS_PER_DAY: Final[str]
SPEED_INCHES_PER_DAY: Final[str]
SPEED_METERS_PER_SECOND: Final[str]
SPEED_INCHES_PER_HOUR: Final[str]
SPEED_KILOMETERS_PER_HOUR: Final[str]
SPEED_MILES_PER_HOUR: Final[str]
SIGNAL_STRENGTH_DECIBELS: Final[str]
SIGNAL_STRENGTH_DECIBELS_MILLIWATT: Final[str]
DATA_BITS: Final[str]
DATA_KILOBITS: Final[str]
DATA_MEGABITS: Final[str]
DATA_GIGABITS: Final[str]
DATA_BYTES: Final[str]
DATA_KILOBYTES: Final[str]
DATA_MEGABYTES: Final[str]
DATA_GIGABYTES: Final[str]
DATA_TERABYTES: Final[str]
DATA_PETABYTES: Final[str]
DATA_EXABYTES: Final[str]
DATA_ZETTABYTES: Final[str]
DATA_YOTTABYTES: Final[str]
DATA_KIBIBYTES: Final[str]
DATA_MEBIBYTES: Final[str]
DATA_GIBIBYTES: Final[str]
DATA_TEBIBYTES: Final[str]
DATA_PEBIBYTES: Final[str]
DATA_EXBIBYTES: Final[str]
DATA_ZEBIBYTES: Final[str]
DATA_YOBIBYTES: Final[str]
DATA_RATE_BITS_PER_SECOND: Final[str]
DATA_RATE_KILOBITS_PER_SECOND: Final[str]
DATA_RATE_MEGABITS_PER_SECOND: Final[str]
DATA_RATE_GIGABITS_PER_SECOND: Final[str]
DATA_RATE_BYTES_PER_SECOND: Final[str]
DATA_RATE_KILOBYTES_PER_SECOND: Final[str]
DATA_RATE_MEGABYTES_PER_SECOND: Final[str]
DATA_RATE_GIGABYTES_PER_SECOND: Final[str]
DATA_RATE_KIBIBYTES_PER_SECOND: Final[str]
DATA_RATE_MEBIBYTES_PER_SECOND: Final[str]
DATA_RATE_GIBIBYTES_PER_SECOND: Final[str]
SERVICE_HOMEASSISTANT_STOP: Final[str]
SERVICE_HOMEASSISTANT_RESTART: Final[str]
SERVICE_TURN_ON: Final[str]
SERVICE_TURN_OFF: Final[str]
SERVICE_TOGGLE: Final[str]
SERVICE_RELOAD: Final[str]
SERVICE_VOLUME_UP: Final[str]
SERVICE_VOLUME_DOWN: Final[str]
SERVICE_VOLUME_MUTE: Final[str]
SERVICE_VOLUME_SET: Final[str]
SERVICE_MEDIA_PLAY_PAUSE: Final[str]
SERVICE_MEDIA_PLAY: Final[str]
SERVICE_MEDIA_PAUSE: Final[str]
SERVICE_MEDIA_STOP: Final[str]
SERVICE_MEDIA_NEXT_TRACK: Final[str]
SERVICE_MEDIA_PREVIOUS_TRACK: Final[str]
SERVICE_MEDIA_SEEK: Final[str]
SERVICE_REPEAT_SET: Final[str]
SERVICE_SHUFFLE_SET: Final[str]
SERVICE_ALARM_DISARM: Final[str]
SERVICE_ALARM_ARM_HOME: Final[str]
SERVICE_ALARM_ARM_AWAY: Final[str]
SERVICE_ALARM_ARM_NIGHT: Final[str]
SERVICE_ALARM_ARM_VACATION: Final[str]
SERVICE_ALARM_ARM_CUSTOM_BYPASS: Final[str]
SERVICE_ALARM_TRIGGER: Final[str]
SERVICE_LOCK: Final[str]
SERVICE_UNLOCK: Final[str]
SERVICE_OPEN: Final[str]
SERVICE_CLOSE: Final[str]
SERVICE_CLOSE_COVER: Final[str]
SERVICE_CLOSE_COVER_TILT: Final[str]
SERVICE_OPEN_COVER: Final[str]
SERVICE_OPEN_COVER_TILT: Final[str]
SERVICE_SET_COVER_POSITION: Final[str]
SERVICE_SET_COVER_TILT_POSITION: Final[str]
SERVICE_STOP_COVER: Final[str]
SERVICE_STOP_COVER_TILT: Final[str]
SERVICE_TOGGLE_COVER_TILT: Final[str]
SERVICE_SELECT_OPTION: Final[str]
SERVER_PORT: Final[int]
URL_ROOT: Final[str]
URL_API: Final[str]
URL_API_STREAM: Final[str]
URL_API_CONFIG: Final[str]
URL_API_DISCOVERY_INFO: Final[str]
URL_API_STATES: Final[str]
URL_API_STATES_ENTITY: Final[str]
URL_API_EVENTS: Final[str]
URL_API_EVENTS_EVENT: Final[str]
URL_API_SERVICES: Final[str]
URL_API_SERVICES_SERVICE: Final[str]
URL_API_COMPONENTS: Final[str]
URL_API_ERROR_LOG: Final[str]
URL_API_LOG_OUT: Final[str]
URL_API_TEMPLATE: Final[str]
HTTP_OK: Final[int]
HTTP_CREATED: Final[int]
HTTP_ACCEPTED: Final[int]
HTTP_MOVED_PERMANENTLY: Final[int]
HTTP_BAD_REQUEST: Final[int]
HTTP_UNAUTHORIZED: Final[int]
HTTP_FORBIDDEN: Final[int]
HTTP_NOT_FOUND: Final[int]
HTTP_METHOD_NOT_ALLOWED: Final[int]
HTTP_UNPROCESSABLE_ENTITY: Final[int]
HTTP_TOO_MANY_REQUESTS: Final[int]
HTTP_INTERNAL_SERVER_ERROR: Final[int]
HTTP_BAD_GATEWAY: Final[int]
HTTP_SERVICE_UNAVAILABLE: Final[int]
HTTP_BASIC_AUTHENTICATION: Final[str]
HTTP_BEARER_AUTHENTICATION: Final[str]
HTTP_DIGEST_AUTHENTICATION: Final[str]
HTTP_HEADER_X_REQUESTED_WITH: Final[str]
CONTENT_TYPE_JSON: Final[str]
CONTENT_TYPE_MULTIPART: Final[str]
CONTENT_TYPE_TEXT_PLAIN: Final[str]
RESTART_EXIT_CODE: Final[int]
UNIT_NOT_RECOGNIZED_TEMPLATE: Final[str]
LENGTH: Final[str]
MASS: Final[str]
PRESSURE: Final[str]
VOLUME: Final[str]
TEMPERATURE: Final[str]
SPEED_MS: Final[str]
ILLUMINANCE: Final[str]
WEEKDAYS: Final[list[str]]
PRECISION_WHOLE: Final[int]
PRECISION_HALVES: Final[float]
PRECISION_TENTHS: Final[float]
CLOUD_NEVER_EXPOSED_ENTITIES: Final[list[str]]
CAST_APP_ID_HOMEASSISTANT: Final[str]



from . import ATTR_SOURCE as ATTR_SOURCE, DOMAIN as DOMAIN, EVENT_AUTOMATION_TRIGGERED as EVENT_AUTOMATION_TRIGGERED
from homeassistant.components.logbook import LazyEventPartialState as LazyEventPartialState
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_NAME as ATTR_NAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_describe_events(hass: HomeAssistant, async_describe_event): ...



from .const import DOMAIN as DOMAIN
from .devolo_device import DevoloDeviceEntity as DevoloDeviceEntity
from devolo_home_control_api.devices.zwave import Zwave as Zwave
from devolo_home_control_api.homecontrol import HomeControl as HomeControl
from homeassistant.components.sensor import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_VOLTAGE as DEVICE_CLASS_VOLTAGE, STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import PERCENTAGE as PERCENTAGE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

DEVICE_CLASS_MAPPING: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DevoloMultiLevelDeviceEntity(DevoloDeviceEntity, SensorEntity):
    @property
    def state(self) -> int: ...

class DevoloGenericMultiLevelDeviceEntity(DevoloMultiLevelDeviceEntity):
    _multi_level_sensor_property: Any
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    _value: Any
    _attr_entity_registry_enabled_default: bool
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str) -> None: ...

class DevoloBatteryEntity(DevoloMultiLevelDeviceEntity):
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    _value: Any
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str) -> None: ...

class DevoloConsumptionEntity(DevoloMultiLevelDeviceEntity):
    _sensor_type: Any
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    _attr_state_class: Any
    _attr_last_reset: Any
    _value: Any
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str, consumption: str) -> None: ...
    @property
    def unique_id(self) -> str: ...
    def _sync(self, message: tuple) -> None: ...



from ..config_flow import CodeInvalid as CodeInvalid, NestAuthError as NestAuthError, register_flow_implementation as register_flow_implementation
from .const import DOMAIN as DOMAIN
from homeassistant.const import HTTP_UNAUTHORIZED as HTTP_UNAUTHORIZED
from homeassistant.core import callback as callback

def initialize(hass, client_id, client_secret) -> None: ...
async def generate_auth_url(client_id, flow_id): ...
async def resolve_auth_code(hass, client_id, client_secret, code): ...



from .const import CONF_SERIAL_NUMBER as CONF_SERIAL_NUMBER, DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigFlow as ConfigFlow
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from typing import Any

class ElgatoFlowHandler(ConfigFlow):
    VERSION: int
    host: str
    port: int
    serial_number: str
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_zeroconf(self, discovery_info: dict[str, Any]) -> FlowResult: ...
    async def async_step_zeroconf_confirm(self, _: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    def _async_show_setup_form(self, errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    def _async_create_entry(self) -> FlowResult: ...
    async def _get_elgato_serial_number(self, raise_on_progress: bool = ...) -> None: ...



from .common import FritzBoxBaseEntity as FritzBoxBaseEntity, FritzBoxTools as FritzBoxTools, FritzData as FritzData, FritzDevice as FritzDevice, FritzDeviceBase as FritzDeviceBase, SwitchInfo as SwitchInfo
from .const import DATA_FRITZ as DATA_FRITZ, DOMAIN as DOMAIN, SWITCH_TYPE_DEFLECTION as SWITCH_TYPE_DEFLECTION, SWITCH_TYPE_PORTFORWARD as SWITCH_TYPE_PORTFORWARD, SWITCH_TYPE_WIFINETWORK as SWITCH_TYPE_WIFINETWORK
from collections import OrderedDict
from homeassistant.components.network import async_get_source_ip as async_get_source_ip
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.util import slugify as slugify
from typing import Any

_LOGGER: Any

async def async_service_call_action(fritzbox_tools: FritzBoxTools, service_name: str, service_suffix: Union[str, None], action_name: str, **kwargs: Any) -> Union[None, dict]: ...
def service_call_action(fritzbox_tools: FritzBoxTools, service_name: str, service_suffix: Union[str, None], action_name: str, **kwargs: Any) -> Union[dict, None]: ...
def get_deflections(fritzbox_tools: FritzBoxTools, service_name: str) -> Union[list[OrderedDict[Any, Any]], None]: ...
def deflection_entities_list(fritzbox_tools: FritzBoxTools, device_friendly_name: str) -> list[FritzBoxDeflectionSwitch]: ...
def port_entities_list(fritzbox_tools: FritzBoxTools, device_friendly_name: str, local_ip: str) -> list[FritzBoxPortSwitch]: ...
def wifi_entities_list(fritzbox_tools: FritzBoxTools, device_friendly_name: str) -> list[FritzBoxWifiSwitch]: ...
def profile_entities_list(router: FritzBoxTools, data_fritz: FritzData) -> list[FritzBoxProfileSwitch]: ...
def all_entities_list(fritzbox_tools: FritzBoxTools, device_friendly_name: str, data_fritz: FritzData, local_ip: str) -> list[Entity]: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class FritzBoxBaseSwitch(FritzBoxBaseEntity):
    _description: Any
    _friendly_name: Any
    _icon: Any
    _type: Any
    _update: Any
    _switch: Any
    _name: Any
    _unique_id: Any
    _attributes: Any
    _is_available: bool
    _attr_is_on: bool
    def __init__(self, fritzbox_tools: FritzBoxTools, device_friendly_name: str, switch_info: SwitchInfo) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def icon(self) -> str: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def available(self) -> bool: ...
    @property
    def extra_state_attributes(self) -> dict[str, str]: ...
    async def async_update(self) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    async def _async_handle_turn_on_off(self, turn_on: bool) -> bool: ...

class FritzBoxPortSwitch(FritzBoxBaseSwitch, SwitchEntity):
    _fritzbox_tools: Any
    _attributes: Any
    connection_type: Any
    port_mapping: Any
    _idx: Any
    def __init__(self, fritzbox_tools: FritzBoxTools, device_friendly_name: str, port_mapping: Union[dict[str, Any], None], idx: int, connection_type: str) -> None: ...
    _is_available: bool
    _attr_is_on: Any
    async def _async_fetch_update(self) -> None: ...
    async def _async_handle_port_switch_on_off(self, turn_on: bool) -> bool: ...

class FritzBoxDeflectionSwitch(FritzBoxBaseSwitch, SwitchEntity):
    _fritzbox_tools: Any
    dict_of_deflection: Any
    _attributes: Any
    id: Any
    def __init__(self, fritzbox_tools: FritzBoxTools, device_friendly_name: str, dict_of_deflection: Any) -> None: ...
    _is_available: bool
    _attr_is_on: Any
    async def _async_fetch_update(self) -> None: ...
    async def _async_switch_on_off_executor(self, turn_on: bool) -> None: ...

class FritzBoxProfileSwitch(FritzDeviceBase, SwitchEntity):
    _attr_icon: str
    _attr_is_on: bool
    _name: Any
    _attr_unique_id: Any
    def __init__(self, fritzbox_tools: FritzBoxTools, device: FritzDevice) -> None: ...
    async def async_process_update(self) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    async def _async_handle_turn_on_off(self, turn_on: bool) -> bool: ...
    async def _async_switch_on_off(self, turn_on: bool) -> None: ...

class FritzBoxWifiSwitch(FritzBoxBaseSwitch, SwitchEntity):
    _fritzbox_tools: Any
    _attributes: Any
    _network_num: Any
    def __init__(self, fritzbox_tools: FritzBoxTools, device_friendly_name: str, network_num: int, network_name: str) -> None: ...
    _is_available: bool
    _attr_is_on: Any
    async def _async_fetch_update(self) -> None: ...
    async def _async_switch_on_off_executor(self, turn_on: bool) -> None: ...



from .const import CONF_ACTION as CONF_ACTION, CONF_HIDE_ENTITY as CONF_HIDE_ENTITY, CONF_INITIAL_STATE as CONF_INITIAL_STATE, CONF_TRACE as CONF_TRACE, CONF_TRIGGER as CONF_TRIGGER, CONF_TRIGGER_VARIABLES as CONF_TRIGGER_VARIABLES, DOMAIN as DOMAIN
from .helpers import async_get_blueprints as async_get_blueprints
from homeassistant.components import blueprint as blueprint
from homeassistant.components.device_automation.exceptions import InvalidDeviceAutomationConfig as InvalidDeviceAutomationConfig
from homeassistant.components.trace import TRACE_CONFIG_SCHEMA as TRACE_CONFIG_SCHEMA
from homeassistant.config import async_log_exception as async_log_exception, config_without_domain as config_without_domain
from homeassistant.const import CONF_ALIAS as CONF_ALIAS, CONF_CONDITION as CONF_CONDITION, CONF_DESCRIPTION as CONF_DESCRIPTION, CONF_ID as CONF_ID, CONF_VARIABLES as CONF_VARIABLES
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import config_per_platform as config_per_platform, script as script
from homeassistant.helpers.condition import async_validate_condition_config as async_validate_condition_config
from homeassistant.helpers.trigger import async_validate_trigger_config as async_validate_trigger_config
from homeassistant.loader import IntegrationNotFound as IntegrationNotFound
from typing import Any

PACKAGE_MERGE_HINT: str
_CONDITION_SCHEMA: Any
PLATFORM_SCHEMA: Any

async def async_validate_config_item(hass, config, full_config: Any | None = ...): ...

class AutomationConfig(dict):
    raw_config: Any

async def _try_async_validate_config_item(hass, config, full_config: Any | None = ...): ...
async def async_validate_config(hass, config): ...



from collections.abc import Mapping
from datetime import datetime
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_CO as DEVICE_CLASS_CO, DEVICE_CLASS_CO2 as DEVICE_CLASS_CO2, DEVICE_CLASS_CURRENT as DEVICE_CLASS_CURRENT, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_MONETARY as DEVICE_CLASS_MONETARY, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_POWER_FACTOR as DEVICE_CLASS_POWER_FACTOR, DEVICE_CLASS_PRESSURE as DEVICE_CLASS_PRESSURE, DEVICE_CLASS_SIGNAL_STRENGTH as DEVICE_CLASS_SIGNAL_STRENGTH, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP, DEVICE_CLASS_VOLTAGE as DEVICE_CLASS_VOLTAGE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final

_LOGGER: Final[Any]
ATTR_LAST_RESET: Final[str]
ATTR_STATE_CLASS: Final[str]
DOMAIN: Final[str]
ENTITY_ID_FORMAT: Final[Any]
SCAN_INTERVAL: Final[Any]
DEVICE_CLASSES: Final[list[str]]
DEVICE_CLASSES_SCHEMA: Final[Any]
STATE_CLASS_MEASUREMENT: Final[str]
STATE_CLASSES: Final[list[str]]
STATE_CLASSES_SCHEMA: Final[Any]

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class SensorEntityDescription(EntityDescription):
    state_class: Union[str, None]
    last_reset: Union[datetime, None]

class SensorEntity(Entity):
    entity_description: SensorEntityDescription
    _attr_state_class: Union[str, None]
    _attr_last_reset: Union[datetime, None]
    @property
    def state_class(self) -> Union[str, None]: ...
    @property
    def last_reset(self) -> Union[datetime, None]: ...
    @property
    def capability_attributes(self) -> Union[Mapping[str, Any], None]: ...
    @property
    def state_attributes(self) -> Union[dict[str, Any], None]: ...



from . import EsphomeEntity as EsphomeEntity, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import CoverInfo, CoverState
from homeassistant.components.cover import ATTR_POSITION as ATTR_POSITION, ATTR_TILT_POSITION as ATTR_TILT_POSITION, CoverEntity as CoverEntity, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_CLOSE_TILT as SUPPORT_CLOSE_TILT, SUPPORT_OPEN as SUPPORT_OPEN, SUPPORT_OPEN_TILT as SUPPORT_OPEN_TILT, SUPPORT_SET_POSITION as SUPPORT_SET_POSITION, SUPPORT_SET_TILT_POSITION as SUPPORT_SET_TILT_POSITION, SUPPORT_STOP as SUPPORT_STOP
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class EsphomeCover(EsphomeEntity[CoverInfo, CoverState], CoverEntity):
    @property
    def supported_features(self) -> int: ...
    @property
    def device_class(self) -> str: ...
    @property
    def assumed_state(self) -> bool: ...
    def is_closed(self) -> Union[bool, None]: ...
    def is_opening(self) -> bool: ...
    def is_closing(self) -> bool: ...
    def current_cover_position(self) -> Union[int, None]: ...
    def current_cover_tilt_position(self) -> Union[int, None]: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **kwargs: Any) -> None: ...
    async def async_set_cover_position(self, **kwargs: int) -> None: ...
    async def async_open_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_close_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_set_cover_tilt_position(self, **kwargs: int) -> None: ...



from .const import CONF_AZIMUTH as CONF_AZIMUTH, CONF_DAMPING as CONF_DAMPING, CONF_DECLINATION as CONF_DECLINATION, CONF_MODULES_POWER as CONF_MODULES_POWER, DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigEntry as ConfigEntry, ConfigFlow as ConfigFlow, OptionsFlow as OptionsFlow
from homeassistant.const import CONF_API_KEY as CONF_API_KEY, CONF_LATITUDE as CONF_LATITUDE, CONF_LONGITUDE as CONF_LONGITUDE, CONF_NAME as CONF_NAME
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

class ForecastSolarFlowHandler(ConfigFlow):
    VERSION: int
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> ForecastSolarOptionFlowHandler: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

class ForecastSolarOptionFlowHandler(OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from . import ShellyDeviceWrapper as ShellyDeviceWrapper
from .const import COAP as COAP, DATA_CONFIG_ENTRY as DATA_CONFIG_ENTRY, DOMAIN as DOMAIN
from .entity import ShellyBlockEntity as ShellyBlockEntity
from aioshelly import Block as Block
from homeassistant.components.cover import ATTR_POSITION as ATTR_POSITION, CoverEntity as CoverEntity, DEVICE_CLASS_SHUTTER as DEVICE_CLASS_SHUTTER, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_OPEN as SUPPORT_OPEN, SUPPORT_SET_POSITION as SUPPORT_SET_POSITION, SUPPORT_STOP as SUPPORT_STOP
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ShellyCover(ShellyBlockEntity, CoverEntity):
    _attr_device_class: Any
    control_result: Any
    _supported_features: Any
    def __init__(self, wrapper: ShellyDeviceWrapper, block: Block) -> None: ...
    @property
    def is_closed(self) -> bool: ...
    @property
    def current_cover_position(self) -> int: ...
    @property
    def is_closing(self) -> bool: ...
    @property
    def is_opening(self) -> bool: ...
    @property
    def supported_features(self) -> int: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_set_cover_position(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **_kwargs: Any) -> None: ...
    def _update_callback(self) -> None: ...



from . import AccuWeatherDataUpdateCoordinator as AccuWeatherDataUpdateCoordinator
from .const import API_IMPERIAL as API_IMPERIAL, API_METRIC as API_METRIC, ATTRIBUTION as ATTRIBUTION, ATTR_FORECAST as ATTR_FORECAST, CONDITION_CLASSES as CONDITION_CLASSES, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER, NAME as NAME
from homeassistant.components.weather import ATTR_FORECAST_CONDITION as ATTR_FORECAST_CONDITION, ATTR_FORECAST_PRECIPITATION as ATTR_FORECAST_PRECIPITATION, ATTR_FORECAST_PRECIPITATION_PROBABILITY as ATTR_FORECAST_PRECIPITATION_PROBABILITY, ATTR_FORECAST_TEMP as ATTR_FORECAST_TEMP, ATTR_FORECAST_TEMP_LOW as ATTR_FORECAST_TEMP_LOW, ATTR_FORECAST_TIME as ATTR_FORECAST_TIME, ATTR_FORECAST_WIND_BEARING as ATTR_FORECAST_WIND_BEARING, ATTR_FORECAST_WIND_SPEED as ATTR_FORECAST_WIND_SPEED, Forecast as Forecast, WeatherEntity as WeatherEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_NAME as CONF_NAME, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity
from homeassistant.util.dt import utc_from_timestamp as utc_from_timestamp
from typing import Any

PARALLEL_UPDATES: int

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class AccuWeatherEntity(CoordinatorEntity, WeatherEntity):
    coordinator: AccuWeatherDataUpdateCoordinator
    _unit_system: Any
    _attr_name: Any
    _attr_unique_id: Any
    _attr_temperature_unit: Any
    _attr_attribution: Any
    _attr_device_info: Any
    def __init__(self, name: str, coordinator: AccuWeatherDataUpdateCoordinator) -> None: ...
    @property
    def condition(self) -> Union[str, None]: ...
    @property
    def temperature(self) -> float: ...
    @property
    def pressure(self) -> float: ...
    @property
    def humidity(self) -> int: ...
    @property
    def wind_speed(self) -> float: ...
    @property
    def wind_bearing(self) -> int: ...
    @property
    def visibility(self) -> float: ...
    @property
    def ozone(self) -> Union[int, None]: ...
    @property
    def forecast(self) -> Union[list[Forecast], None]: ...
    @staticmethod
    def _calc_precipitation(day: dict[str, Any]) -> float: ...



from . import ATTR_POSITION as ATTR_POSITION, ATTR_TILT_POSITION as ATTR_TILT_POSITION, DOMAIN as DOMAIN, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_CLOSE_TILT as SUPPORT_CLOSE_TILT, SUPPORT_OPEN as SUPPORT_OPEN, SUPPORT_OPEN_TILT as SUPPORT_OPEN_TILT, SUPPORT_SET_POSITION as SUPPORT_SET_POSITION, SUPPORT_SET_TILT_POSITION as SUPPORT_SET_TILT_POSITION, SUPPORT_STOP as SUPPORT_STOP
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_TYPE as CONF_TYPE, SERVICE_CLOSE_COVER as SERVICE_CLOSE_COVER, SERVICE_CLOSE_COVER_TILT as SERVICE_CLOSE_COVER_TILT, SERVICE_OPEN_COVER as SERVICE_OPEN_COVER, SERVICE_OPEN_COVER_TILT as SERVICE_OPEN_COVER_TILT, SERVICE_SET_COVER_POSITION as SERVICE_SET_COVER_POSITION, SERVICE_SET_COVER_TILT_POSITION as SERVICE_SET_COVER_TILT_POSITION, SERVICE_STOP_COVER as SERVICE_STOP_COVER
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.entity import get_supported_features as get_supported_features
from typing import Any

CMD_ACTION_TYPES: Any
POSITION_ACTION_TYPES: Any
CMD_ACTION_SCHEMA: Any
POSITION_ACTION_SCHEMA: Any
ACTION_SCHEMA: Any

async def async_get_actions(hass: HomeAssistant, device_id: str) -> list[dict]: ...
async def async_get_action_capabilities(hass: HomeAssistant, config: dict) -> dict: ...
async def async_call_action_from_config(hass: HomeAssistant, config: dict, variables: dict, context: Union[Context, None]) -> None: ...



from .const import SECRET_YAML as SECRET_YAML
from .dumper import dump as dump, save_yaml as save_yaml
from .input import UndefinedSubstitution as UndefinedSubstitution, extract_inputs as extract_inputs, substitute as substitute
from .loader import Secrets as Secrets, load_yaml as load_yaml, parse_yaml as parse_yaml, secret_yaml as secret_yaml
from .objects import Input as Input



from homeassistant.components.geo_location import DOMAIN as DOMAIN
from homeassistant.const import CONF_EVENT as CONF_EVENT, CONF_PLATFORM as CONF_PLATFORM, CONF_SOURCE as CONF_SOURCE, CONF_ZONE as CONF_ZONE
from homeassistant.core import HassJob as HassJob, callback as callback
from homeassistant.helpers import condition as condition
from homeassistant.helpers.config_validation import entity_domain as entity_domain
from homeassistant.helpers.event import TrackStates as TrackStates, async_track_state_change_filtered as async_track_state_change_filtered
from typing import Any

_LOGGER: Any
EVENT_ENTER: str
EVENT_LEAVE: str
DEFAULT_EVENT = EVENT_ENTER
TRIGGER_SCHEMA: Any

def source_match(state, source): ...
async def async_attach_trigger(hass, config, action, automation_info): ...



from . import api as api, config_flow as config_flow
from .const import AUTH as AUTH, CONF_CLOUDHOOK_URL as CONF_CLOUDHOOK_URL, DATA_CAMERAS as DATA_CAMERAS, DATA_DEVICE_IDS as DATA_DEVICE_IDS, DATA_EVENTS as DATA_EVENTS, DATA_HANDLER as DATA_HANDLER, DATA_HOMES as DATA_HOMES, DATA_PERSONS as DATA_PERSONS, DATA_SCHEDULES as DATA_SCHEDULES, DOMAIN as DOMAIN, OAUTH2_AUTHORIZE as OAUTH2_AUTHORIZE, OAUTH2_TOKEN as OAUTH2_TOKEN, PLATFORMS as PLATFORMS, WEBHOOK_ACTIVATION as WEBHOOK_ACTIVATION, WEBHOOK_DEACTIVATION as WEBHOOK_DEACTIVATION, WEBHOOK_PUSH_TYPE as WEBHOOK_PUSH_TYPE
from .data_handler import NetatmoDataHandler as NetatmoDataHandler
from .webhook import async_handle_webhook as async_handle_webhook
from homeassistant.components import cloud as cloud
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_CLIENT_ID as CONF_CLIENT_ID, CONF_CLIENT_SECRET as CONF_CLIENT_SECRET, CONF_WEBHOOK_ID as CONF_WEBHOOK_ID, EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import CoreState as CoreState, HomeAssistant as HomeAssistant
from homeassistant.helpers import aiohttp_client as aiohttp_client, config_entry_oauth2_flow as config_entry_oauth2_flow
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.event import async_call_later as async_call_later
from typing import Any

_LOGGER: Any
CONFIG_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: dict) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_config_entry_updated(hass: HomeAssistant, entry: ConfigEntry) -> None: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_remove_entry(hass: HomeAssistant, entry: ConfigEntry) -> None: ...



from .const import CONF_MOUNT_DIR as CONF_MOUNT_DIR, CONF_TYPE_OWSERVER as CONF_TYPE_OWSERVER, CONF_TYPE_SYSBUS as CONF_TYPE_SYSBUS, DEFAULT_OWSERVER_HOST as DEFAULT_OWSERVER_HOST, DEFAULT_OWSERVER_PORT as DEFAULT_OWSERVER_PORT, DEFAULT_SYSBUS_MOUNT_DIR as DEFAULT_SYSBUS_MOUNT_DIR, DOMAIN as DOMAIN
from .onewirehub import CannotConnect as CannotConnect, InvalidPath as InvalidPath, OneWireHub as OneWireHub
from homeassistant.config_entries import ConfigFlow as ConfigFlow
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

DATA_SCHEMA_USER: Any
DATA_SCHEMA_OWSERVER: Any
DATA_SCHEMA_MOUNTDIR: Any

async def validate_input_owserver(hass: HomeAssistant, data: dict[str, Any]) -> dict[str, str]: ...
async def validate_input_mount_dir(hass: HomeAssistant, data: dict[str, Any]) -> dict[str, str]: ...

class OneWireFlowHandler(ConfigFlow):
    VERSION: int
    onewire_config: Any
    def __init__(self) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_owserver(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_mount_dir(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_import(self, platform_config: dict[str, Any]) -> FlowResult: ...



from .const import ATTR_OPTION as ATTR_OPTION, ATTR_OPTIONS as ATTR_OPTIONS, CONF_OPTION as CONF_OPTION, DOMAIN as DOMAIN, SERVICE_SELECT_OPTION as SERVICE_SELECT_OPTION
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_TYPE as CONF_TYPE
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, HomeAssistantError as HomeAssistantError
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.entity import get_capability as get_capability
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

ACTION_TYPES: Any
ACTION_SCHEMA: Any

async def async_get_actions(hass: HomeAssistant, device_id: str) -> list[dict]: ...
async def async_call_action_from_config(hass: HomeAssistant, config: dict, variables: dict, context: Union[Context, None]) -> None: ...
async def async_get_action_capabilities(hass: HomeAssistant, config: ConfigType) -> dict[str, Any]: ...



from .entity import BlockAttributeDescription as BlockAttributeDescription, RestAttributeDescription as RestAttributeDescription, ShellyBlockAttributeEntity as ShellyBlockAttributeEntity, ShellyRestAttributeEntity as ShellyRestAttributeEntity, ShellySleepingBlockAttributeEntity as ShellySleepingBlockAttributeEntity, async_setup_entry_attribute_entities as async_setup_entry_attribute_entities, async_setup_entry_rest as async_setup_entry_rest
from .utils import is_momentary_input as is_momentary_input
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_OPENING as DEVICE_CLASS_OPENING, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_PROBLEM as DEVICE_CLASS_PROBLEM, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_VIBRATION as DEVICE_CLASS_VIBRATION, STATE_ON as STATE_ON
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any, Final

SENSORS: Final[Any]
REST_SENSORS: Final[Any]

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ShellyBinarySensor(ShellyBlockAttributeEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...

class ShellyRestBinarySensor(ShellyRestAttributeEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...

class ShellySleepingBinarySensor(ShellySleepingBlockAttributeEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...



from . import const as const, decorators as decorators, messages as messages
from .connection import ActiveConnection as ActiveConnection
from collections.abc import Callable as Callable
from homeassistant.auth.permissions.const import CAT_ENTITIES as CAT_ENTITIES, POLICY_READ as POLICY_READ
from homeassistant.bootstrap import SIGNAL_BOOTSTRAP_INTEGRATONS as SIGNAL_BOOTSTRAP_INTEGRATONS
from homeassistant.components.websocket_api.const import ERR_NOT_FOUND as ERR_NOT_FOUND
from homeassistant.const import EVENT_STATE_CHANGED as EVENT_STATE_CHANGED, EVENT_TIME_CHANGED as EVENT_TIME_CHANGED, MATCH_ALL as MATCH_ALL
from homeassistant.core import Context as Context, Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError, ServiceNotFound as ServiceNotFound, TemplateError as TemplateError, Unauthorized as Unauthorized
from homeassistant.helpers import entity as entity, template as template
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.event import TrackTemplate as TrackTemplate, TrackTemplateResult as TrackTemplateResult, async_track_template_result as async_track_template_result
from homeassistant.helpers.json import ExtendedJSONEncoder as ExtendedJSONEncoder
from homeassistant.helpers.service import async_get_all_descriptions as async_get_all_descriptions
from homeassistant.loader import IntegrationNotFound as IntegrationNotFound, async_get_integration as async_get_integration
from homeassistant.setup import DATA_SETUP_TIME as DATA_SETUP_TIME, async_get_loaded_integrations as async_get_loaded_integrations
from typing import Any

def async_register_commands(hass: HomeAssistant, async_reg: Callable[[HomeAssistant, const.WebSocketCommandHandler], None]) -> None: ...
def pong_message(iden: int) -> dict[str, Any]: ...
def handle_subscribe_events(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_subscribe_bootstrap_integrations(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_unsubscribe_events(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_call_service(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_get_states(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_get_services(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_get_config(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_manifest_list(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_manifest_get(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_integration_setup_info(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_ping(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_render_template(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
def handle_entity_source(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_subscribe_trigger(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_test_condition(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...
async def handle_execute_script(hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]) -> None: ...



from .const import ATTR_OPTION as ATTR_OPTION, ATTR_OPTIONS as ATTR_OPTIONS, DOMAIN as DOMAIN, SERVICE_SELECT_OPTION as SERVICE_SELECT_OPTION
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

SCAN_INTERVAL: Any
ENTITY_ID_FORMAT: Any
MIN_TIME_BETWEEN_SCANS: Any
_LOGGER: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class SelectEntityDescription(EntityDescription): ...

class SelectEntity(Entity):
    entity_description: SelectEntityDescription
    _attr_current_option: Union[str, None]
    _attr_options: list[str]
    _attr_state: None
    @property
    def capability_attributes(self) -> dict[str, Any]: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def options(self) -> list[str]: ...
    @property
    def current_option(self) -> Union[str, None]: ...
    def select_option(self, option: str) -> None: ...
    async def async_select_option(self, option: str) -> None: ...



DOMAIN: str
CONF_DEVICE_PASSWORD: str
CONF_PHONE_ID: str
DATA_BRIDGE: str
DATA_DEVICE: str
DATA_DISCOVERY: str
DISCOVERY_TIME_SEC: int
SIGNAL_DEVICE_ADD: str
CONF_AUTO_OFF: str
CONF_TIMER_MINUTES: str
SERVICE_SET_AUTO_OFF_NAME: str
SERVICE_TURN_ON_WITH_TIMER_NAME: str
MAX_UPDATE_INTERVAL_SEC: int



from typing import Any, Callable

_LOGGER: Any

class Subscriber:
    name: Any
    callback: Any
    def __init__(self, name: str, callback: Callable) -> None: ...
    def update(self, message: str) -> None: ...



from . import STATE_CLEANING as STATE_CLEANING, STATE_ERROR as STATE_ERROR, STATE_RETURNING as STATE_RETURNING
from homeassistant.components.group import GroupIntegrationRegistry as GroupIntegrationRegistry
from homeassistant.const import STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_describe_on_off_states(hass: HomeAssistant, registry: GroupIntegrationRegistry) -> None: ...



from .const import ACCOUNT_HASH as ACCOUNT_HASH, COORDINATORS as COORDINATORS, DEVICES as DEVICES, DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from pyrituals import Diffuser as Diffuser
from typing import Any

PLATFORMS: Any
_LOGGER: Any
UPDATE_INTERVAL: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class RitualsDataUpdateCoordinator(DataUpdateCoordinator):
    _device: Any
    def __init__(self, hass: HomeAssistant, device: Diffuser) -> None: ...
    async def _async_update_data(self) -> None: ...



from . import AmbientWeatherEntity as AmbientWeatherEntity, SENSOR_TYPES as SENSOR_TYPES, TYPE_BATT1 as TYPE_BATT1, TYPE_BATT10 as TYPE_BATT10, TYPE_BATT2 as TYPE_BATT2, TYPE_BATT3 as TYPE_BATT3, TYPE_BATT4 as TYPE_BATT4, TYPE_BATT5 as TYPE_BATT5, TYPE_BATT6 as TYPE_BATT6, TYPE_BATT7 as TYPE_BATT7, TYPE_BATT8 as TYPE_BATT8, TYPE_BATT9 as TYPE_BATT9, TYPE_BATTOUT as TYPE_BATTOUT, TYPE_BATT_CO2 as TYPE_BATT_CO2, TYPE_PM25IN_BATT as TYPE_PM25IN_BATT, TYPE_PM25_BATT as TYPE_PM25_BATT
from .const import ATTR_LAST_DATA as ATTR_LAST_DATA, ATTR_MONITORED_CONDITIONS as ATTR_MONITORED_CONDITIONS, DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_NAME as ATTR_NAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class AmbientWeatherBinarySensor(AmbientWeatherEntity, BinarySensorEntity):
    _attr_is_on: Any
    def update_from_latest_data(self) -> None: ...



from homeassistant.components.sensor import SensorEntityDescription as SensorEntityDescription
from typing import Callable

class AirlySensorEntityDescription(SensorEntityDescription):
    value: Callable



from . import get_hyperion_device_id as get_hyperion_device_id, get_hyperion_unique_id as get_hyperion_unique_id, listen_for_instance_updates as listen_for_instance_updates
from .const import CONF_EFFECT_HIDE_LIST as CONF_EFFECT_HIDE_LIST, CONF_INSTANCE_CLIENTS as CONF_INSTANCE_CLIENTS, CONF_PRIORITY as CONF_PRIORITY, DEFAULT_ORIGIN as DEFAULT_ORIGIN, DEFAULT_PRIORITY as DEFAULT_PRIORITY, DOMAIN as DOMAIN, HYPERION_MANUFACTURER_NAME as HYPERION_MANUFACTURER_NAME, HYPERION_MODEL_NAME as HYPERION_MODEL_NAME, NAME_SUFFIX_HYPERION_LIGHT as NAME_SUFFIX_HYPERION_LIGHT, NAME_SUFFIX_HYPERION_PRIORITY_LIGHT as NAME_SUFFIX_HYPERION_PRIORITY_LIGHT, SIGNAL_ENTITY_REMOVE as SIGNAL_ENTITY_REMOVE, TYPE_HYPERION_LIGHT as TYPE_HYPERION_LIGHT, TYPE_HYPERION_PRIORITY_LIGHT as TYPE_HYPERION_PRIORITY_LIGHT
from collections.abc import Sequence
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_EFFECT as ATTR_EFFECT, ATTR_HS_COLOR as ATTR_HS_COLOR, LightEntity as LightEntity, SUPPORT_BRIGHTNESS as SUPPORT_BRIGHTNESS, SUPPORT_COLOR as SUPPORT_COLOR, SUPPORT_EFFECT as SUPPORT_EFFECT
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from hyperion import client as client
from types import MappingProxyType
from typing import Any

_LOGGER: Any
COLOR_BLACK: Any
CONF_DEFAULT_COLOR: str
CONF_HDMI_PRIORITY: str
CONF_EFFECT_LIST: str
KEY_EFFECT_SOLID: str
DEFAULT_COLOR: Any
DEFAULT_BRIGHTNESS: int
DEFAULT_EFFECT = KEY_EFFECT_SOLID
DEFAULT_NAME: str
DEFAULT_PORT: Any
DEFAULT_HDMI_PRIORITY: int
DEFAULT_EFFECT_LIST: list[str]
SUPPORT_HYPERION: Any
ICON_LIGHTBULB: str
ICON_EFFECT: str
ICON_EXTERNAL_SOURCE: str

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> bool: ...

class HyperionBaseLight(LightEntity):
    _unique_id: Any
    _name: Any
    _device_id: Any
    _instance_name: Any
    _options: Any
    _client: Any
    _brightness: int
    _rgb_color: Any
    _effect: Any
    _static_effect_list: Any
    _effect_list: Any
    _client_callbacks: Any
    def __init__(self, server_id: str, instance_num: int, instance_name: str, options: MappingProxyType[str, Any], hyperion_client: client.HyperionClient) -> None: ...
    def _compute_unique_id(self, server_id: str, instance_num: int) -> str: ...
    def _compute_name(self, instance_name: str) -> str: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def name(self) -> str: ...
    @property
    def brightness(self) -> int: ...
    @property
    def hs_color(self) -> tuple[float, float]: ...
    @property
    def icon(self) -> str: ...
    @property
    def effect(self) -> str: ...
    @property
    def effect_list(self) -> list[str]: ...
    @property
    def supported_features(self) -> int: ...
    @property
    def available(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    def _get_option(self, key: str) -> Any: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    def _set_internal_state(self, brightness: Union[int, None] = ..., rgb_color: Union[Sequence[int], None] = ..., effect: Union[str, None] = ...) -> None: ...
    def _update_components(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    def _update_adjustment(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    def _update_priorities(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    def _update_effect_list(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    def _update_full_state(self) -> None: ...
    def _update_client(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def _support_external_effects(self) -> bool: ...
    def _get_priority_entry_that_dictates_state(self) -> Union[dict[str, Any], None]: ...
    def _allow_priority_update(self, priority: Union[dict[str, Any], None] = ...) -> bool: ...

class HyperionLight(HyperionBaseLight):
    def _compute_unique_id(self, server_id: str, instance_num: int) -> str: ...
    def _compute_name(self, instance_name: str) -> str: ...
    @property
    def is_on(self) -> bool: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...

class HyperionPriorityLight(HyperionBaseLight):
    def _compute_unique_id(self, server_id: str, instance_num: int) -> str: ...
    def _compute_name(self, instance_name: str) -> str: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def is_on(self) -> bool: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    @property
    def _support_external_effects(self) -> bool: ...
    def _get_priority_entry_that_dictates_state(self) -> Union[dict[str, Any], None]: ...
    @classmethod
    def _is_priority_entry_black(cls, priority: Union[dict[str, Any], None]) -> bool: ...
    def _allow_priority_update(self, priority: Union[dict[str, Any], None] = ...) -> bool: ...

LIGHT_TYPES: Any



from .const import DOMAIN as DOMAIN, PREF_PRELOAD_STREAM as PREF_PRELOAD_STREAM
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.typing import UNDEFINED as UNDEFINED, UndefinedType as UndefinedType
from typing import Any, Final

STORAGE_KEY: Final[Any]
STORAGE_VERSION: Final[int]

class CameraEntityPreferences:
    _prefs: Any
    def __init__(self, prefs: dict[str, bool]) -> None: ...
    def as_dict(self) -> dict[str, bool]: ...
    @property
    def preload_stream(self) -> bool: ...

class CameraPreferences:
    _hass: Any
    _store: Any
    _prefs: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_initialize(self) -> None: ...
    async def async_update(self, entity_id: str, *, preload_stream: Union[bool, UndefinedType] = ..., stream_options: Union[dict[str, str], UndefinedType] = ...) -> None: ...
    def get(self, entity_id: str) -> CameraEntityPreferences: ...



from .const import CONF_KEYS as CONF_KEYS, CONF_LED as CONF_LED, CONF_OUTPUT as CONF_OUTPUT, CONF_PCK as CONF_PCK, CONF_RELVARREF as CONF_RELVARREF, CONF_ROW as CONF_ROW, CONF_SETPOINT as CONF_SETPOINT, CONF_TABLE as CONF_TABLE, CONF_TEXT as CONF_TEXT, CONF_TIME as CONF_TIME, CONF_TIME_UNIT as CONF_TIME_UNIT, CONF_TRANSITION as CONF_TRANSITION, CONF_VALUE as CONF_VALUE, CONF_VARIABLE as CONF_VARIABLE, DOMAIN as DOMAIN, LED_PORTS as LED_PORTS, LED_STATUS as LED_STATUS, OUTPUT_PORTS as OUTPUT_PORTS, RELVARREF as RELVARREF, SENDKEYCOMMANDS as SENDKEYCOMMANDS, SETPOINTS as SETPOINTS, THRESHOLDS as THRESHOLDS, TIME_UNITS as TIME_UNITS, VARIABLES as VARIABLES, VAR_UNITS as VAR_UNITS
from .helpers import DeviceConnectionType as DeviceConnectionType, get_device_connection as get_device_connection, is_address as is_address, is_states_string as is_states_string
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_BRIGHTNESS as CONF_BRIGHTNESS, CONF_HOST as CONF_HOST, CONF_STATE as CONF_STATE, CONF_UNIT_OF_MEASUREMENT as CONF_UNIT_OF_MEASUREMENT, TIME_SECONDS as TIME_SECONDS
from homeassistant.core import HomeAssistant as HomeAssistant, ServiceCall as ServiceCall
from typing import Any

class LcnServiceCall:
    schema: Any
    hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def get_device_connection(self, service: ServiceCall) -> DeviceConnectionType: ...
    async def async_call_service(self, service: ServiceCall) -> None: ...

class OutputAbs(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class OutputRel(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class OutputToggle(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class Relays(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class Led(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class VarAbs(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class VarReset(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class VarRel(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class LockRegulator(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class SendKeys(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class LockKeys(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class DynText(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

class Pck(LcnServiceCall):
    schema: Any
    async def async_call_service(self, service: ServiceCall) -> None: ...

SERVICES: Any



from .const import DOMAIN as DOMAIN
from .knx_entity import KnxEntity as KnxEntity
from .schema import CoverSchema as CoverSchema
from datetime import datetime
from homeassistant.components.cover import ATTR_POSITION as ATTR_POSITION, ATTR_TILT_POSITION as ATTR_TILT_POSITION, CoverEntity as CoverEntity, DEVICE_CLASS_BLIND as DEVICE_CLASS_BLIND, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_CLOSE_TILT as SUPPORT_CLOSE_TILT, SUPPORT_OPEN as SUPPORT_OPEN, SUPPORT_OPEN_TILT as SUPPORT_OPEN_TILT, SUPPORT_SET_POSITION as SUPPORT_SET_POSITION, SUPPORT_SET_TILT_POSITION as SUPPORT_SET_TILT_POSITION, SUPPORT_STOP as SUPPORT_STOP, SUPPORT_STOP_TILT as SUPPORT_STOP_TILT
from homeassistant.const import CONF_DEVICE_CLASS as CONF_DEVICE_CLASS, CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.event import async_track_utc_time_change as async_track_utc_time_change
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any
from xknx import XKNX as XKNX
from xknx.devices import Cover as XknxCover, Device as XknxDevice

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
def _async_migrate_unique_id(hass: HomeAssistant, platform_config: list[ConfigType]) -> None: ...

class KNXCover(KnxEntity, CoverEntity):
    _device: XknxCover
    _unsubscribe_auto_updater: Any
    _attr_device_class: Any
    _attr_supported_features: Any
    _attr_unique_id: Any
    def __init__(self, xknx: XKNX, config: ConfigType) -> None: ...
    async def after_update_callback(self, device: XknxDevice) -> None: ...
    @property
    def current_cover_position(self) -> Union[int, None]: ...
    @property
    def is_closed(self) -> Union[bool, None]: ...
    @property
    def is_opening(self) -> bool: ...
    @property
    def is_closing(self) -> bool: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_set_cover_position(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **kwargs: Any) -> None: ...
    @property
    def current_cover_tilt_position(self) -> Union[int, None]: ...
    async def async_set_cover_tilt_position(self, **kwargs: Any) -> None: ...
    async def async_open_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_close_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_stop_cover_tilt(self, **kwargs: Any) -> None: ...
    def start_auto_updater(self) -> None: ...
    def stop_auto_updater(self) -> None: ...
    def auto_updater_hook(self, now: datetime) -> None: ...



import voluptuous as vol
from . import DOMAIN as DOMAIN
from .const import ATTR_COMMAND_CLASS as ATTR_COMMAND_CLASS, ATTR_ENDPOINT as ATTR_ENDPOINT, ATTR_PROPERTY as ATTR_PROPERTY, ATTR_PROPERTY_KEY as ATTR_PROPERTY_KEY, ATTR_VALUE as ATTR_VALUE
from .helpers import async_get_node_from_device_id as async_get_node_from_device_id, get_zwave_value_from_config as get_zwave_value_from_config
from homeassistant.const import CONF_CONDITION as CONF_CONDITION, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import condition as condition
from homeassistant.helpers.config_validation import DEVICE_CONDITION_BASE_SCHEMA as DEVICE_CONDITION_BASE_SCHEMA
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from typing import Any

CONF_SUBTYPE: str
CONF_VALUE_ID: str
CONF_STATUS: str
NODE_STATUS_TYPE: str
NODE_STATUS_TYPES: Any
CONFIG_PARAMETER_TYPE: str
VALUE_TYPE: str
CONDITION_TYPES: Any
NODE_STATUS_CONDITION_SCHEMA: Any
CONFIG_PARAMETER_CONDITION_SCHEMA: Any
VALUE_CONDITION_SCHEMA: Any
CONDITION_SCHEMA: Any

async def async_validate_condition_config(hass: HomeAssistant, config: ConfigType) -> ConfigType: ...
async def async_get_conditions(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
def async_condition_from_config(config: ConfigType, config_validation: bool) -> condition.ConditionCheckerType: ...
async def async_get_condition_capabilities(hass: HomeAssistant, config: ConfigType) -> dict[str, vol.Schema]: ...



from typing import Any

ATTR_APP_ID: str
ATTR_APP_NAME: str
ATTR_GROUP_MEMBERS: str
ATTR_INPUT_SOURCE: str
ATTR_INPUT_SOURCE_LIST: str
ATTR_MEDIA_ALBUM_ARTIST: str
ATTR_MEDIA_ALBUM_NAME: str
ATTR_MEDIA_ARTIST: str
ATTR_MEDIA_CHANNEL: str
ATTR_MEDIA_CONTENT_ID: str
ATTR_MEDIA_CONTENT_TYPE: str
ATTR_MEDIA_DURATION: str
ATTR_MEDIA_ENQUEUE: str
ATTR_MEDIA_EXTRA: str
ATTR_MEDIA_EPISODE: str
ATTR_MEDIA_PLAYLIST: str
ATTR_MEDIA_POSITION: str
ATTR_MEDIA_POSITION_UPDATED_AT: str
ATTR_MEDIA_REPEAT: str
ATTR_MEDIA_SEASON: str
ATTR_MEDIA_SEEK_POSITION: str
ATTR_MEDIA_SERIES_TITLE: str
ATTR_MEDIA_SHUFFLE: str
ATTR_MEDIA_TITLE: str
ATTR_MEDIA_TRACK: str
ATTR_MEDIA_VOLUME_LEVEL: str
ATTR_MEDIA_VOLUME_MUTED: str
ATTR_SOUND_MODE: str
ATTR_SOUND_MODE_LIST: str
DOMAIN: str
MEDIA_CLASS_ALBUM: str
MEDIA_CLASS_APP: str
MEDIA_CLASS_ARTIST: str
MEDIA_CLASS_CHANNEL: str
MEDIA_CLASS_COMPOSER: str
MEDIA_CLASS_CONTRIBUTING_ARTIST: str
MEDIA_CLASS_DIRECTORY: str
MEDIA_CLASS_EPISODE: str
MEDIA_CLASS_GAME: str
MEDIA_CLASS_GENRE: str
MEDIA_CLASS_IMAGE: str
MEDIA_CLASS_MOVIE: str
MEDIA_CLASS_MUSIC: str
MEDIA_CLASS_PLAYLIST: str
MEDIA_CLASS_PODCAST: str
MEDIA_CLASS_SEASON: str
MEDIA_CLASS_TRACK: str
MEDIA_CLASS_TV_SHOW: str
MEDIA_CLASS_URL: str
MEDIA_CLASS_VIDEO: str
MEDIA_TYPE_ALBUM: str
MEDIA_TYPE_APP: str
MEDIA_TYPE_APPS: str
MEDIA_TYPE_ARTIST: str
MEDIA_TYPE_CHANNEL: str
MEDIA_TYPE_CHANNELS: str
MEDIA_TYPE_COMPOSER: str
MEDIA_TYPE_CONTRIBUTING_ARTIST: str
MEDIA_TYPE_EPISODE: str
MEDIA_TYPE_GAME: str
MEDIA_TYPE_GENRE: str
MEDIA_TYPE_IMAGE: str
MEDIA_TYPE_MOVIE: str
MEDIA_TYPE_MUSIC: str
MEDIA_TYPE_PLAYLIST: str
MEDIA_TYPE_PODCAST: str
MEDIA_TYPE_SEASON: str
MEDIA_TYPE_TRACK: str
MEDIA_TYPE_TVSHOW: str
MEDIA_TYPE_URL: str
MEDIA_TYPE_VIDEO: str
SERVICE_CLEAR_PLAYLIST: str
SERVICE_JOIN: str
SERVICE_PLAY_MEDIA: str
SERVICE_SELECT_SOUND_MODE: str
SERVICE_SELECT_SOURCE: str
SERVICE_UNJOIN: str
REPEAT_MODE_ALL: str
REPEAT_MODE_OFF: str
REPEAT_MODE_ONE: str
REPEAT_MODES: Any
SUPPORT_PAUSE: int
SUPPORT_SEEK: int
SUPPORT_VOLUME_SET: int
SUPPORT_VOLUME_MUTE: int
SUPPORT_PREVIOUS_TRACK: int
SUPPORT_NEXT_TRACK: int
SUPPORT_TURN_ON: int
SUPPORT_TURN_OFF: int
SUPPORT_PLAY_MEDIA: int
SUPPORT_VOLUME_STEP: int
SUPPORT_SELECT_SOURCE: int
SUPPORT_STOP: int
SUPPORT_CLEAR_PLAYLIST: int
SUPPORT_PLAY: int
SUPPORT_SHUFFLE_SET: int
SUPPORT_SELECT_SOUND_MODE: int
SUPPORT_BROWSE_MEDIA: int
SUPPORT_REPEAT_SET: int
SUPPORT_GROUPING: int



from . import GroupEntity as GroupEntity
from homeassistant.components.cover import ATTR_CURRENT_POSITION as ATTR_CURRENT_POSITION, ATTR_CURRENT_TILT_POSITION as ATTR_CURRENT_TILT_POSITION, ATTR_POSITION as ATTR_POSITION, ATTR_TILT_POSITION as ATTR_TILT_POSITION, CoverEntity as CoverEntity, DOMAIN as DOMAIN, PLATFORM_SCHEMA as PLATFORM_SCHEMA, SERVICE_CLOSE_COVER as SERVICE_CLOSE_COVER, SERVICE_CLOSE_COVER_TILT as SERVICE_CLOSE_COVER_TILT, SERVICE_OPEN_COVER as SERVICE_OPEN_COVER, SERVICE_OPEN_COVER_TILT as SERVICE_OPEN_COVER_TILT, SERVICE_SET_COVER_POSITION as SERVICE_SET_COVER_POSITION, SERVICE_SET_COVER_TILT_POSITION as SERVICE_SET_COVER_TILT_POSITION, SERVICE_STOP_COVER as SERVICE_STOP_COVER, SERVICE_STOP_COVER_TILT as SERVICE_STOP_COVER_TILT, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_CLOSE_TILT as SUPPORT_CLOSE_TILT, SUPPORT_OPEN as SUPPORT_OPEN, SUPPORT_OPEN_TILT as SUPPORT_OPEN_TILT, SUPPORT_SET_POSITION as SUPPORT_SET_POSITION, SUPPORT_SET_TILT_POSITION as SUPPORT_SET_TILT_POSITION, SUPPORT_STOP as SUPPORT_STOP, SUPPORT_STOP_TILT as SUPPORT_STOP_TILT
from homeassistant.const import ATTR_ASSUMED_STATE as ATTR_ASSUMED_STATE, ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_SUPPORTED_FEATURES as ATTR_SUPPORTED_FEATURES, CONF_ENTITIES as CONF_ENTITIES, CONF_NAME as CONF_NAME, CONF_UNIQUE_ID as CONF_UNIQUE_ID, STATE_CLOSING as STATE_CLOSING, STATE_OPEN as STATE_OPEN, STATE_OPENING as STATE_OPENING
from homeassistant.core import CoreState as CoreState, Event as Event, HomeAssistant as HomeAssistant, State as State
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.event import async_track_state_change_event as async_track_state_change_event
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

KEY_OPEN_CLOSE: str
KEY_STOP: str
KEY_POSITION: str
DEFAULT_NAME: str

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[dict[str, Any], None] = ...) -> None: ...

class CoverGroup(GroupEntity, CoverEntity):
    _attr_is_closed: Union[bool, None]
    _attr_is_opening: Union[bool, None]
    _attr_is_closing: Union[bool, None]
    _attr_current_cover_position: Union[int, None]
    _attr_assumed_state: bool
    _entities: Any
    _covers: Any
    _tilts: Any
    _attr_name: Any
    _attr_extra_state_attributes: Any
    _attr_unique_id: Any
    def __init__(self, unique_id: Union[str, None], name: str, entities: list[str]) -> None: ...
    async def _update_supported_features_event(self, event: Event) -> None: ...
    async def async_update_supported_features(self, entity_id: str, new_state: Union[State, None], update_state: bool = ...) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **kwargs: Any) -> None: ...
    async def async_set_cover_position(self, **kwargs: Any) -> None: ...
    async def async_open_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_close_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_stop_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_set_cover_tilt_position(self, **kwargs: Any) -> None: ...
    _attr_current_cover_tilt_position: Any
    _attr_supported_features: Any
    async def async_update(self) -> None: ...



from . import EsphomeEntity as EsphomeEntity, EsphomeEnumMapper as EsphomeEnumMapper, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import ClimateAction, ClimateFanMode, ClimateInfo, ClimateMode, ClimatePreset, ClimateState, ClimateSwingMode
from homeassistant.components.climate import ClimateEntity as ClimateEntity
from homeassistant.components.climate.const import ATTR_HVAC_MODE as ATTR_HVAC_MODE, ATTR_TARGET_TEMP_HIGH as ATTR_TARGET_TEMP_HIGH, ATTR_TARGET_TEMP_LOW as ATTR_TARGET_TEMP_LOW, CURRENT_HVAC_COOL as CURRENT_HVAC_COOL, CURRENT_HVAC_DRY as CURRENT_HVAC_DRY, CURRENT_HVAC_FAN as CURRENT_HVAC_FAN, CURRENT_HVAC_HEAT as CURRENT_HVAC_HEAT, CURRENT_HVAC_IDLE as CURRENT_HVAC_IDLE, CURRENT_HVAC_OFF as CURRENT_HVAC_OFF, FAN_AUTO as FAN_AUTO, FAN_DIFFUSE as FAN_DIFFUSE, FAN_FOCUS as FAN_FOCUS, FAN_HIGH as FAN_HIGH, FAN_LOW as FAN_LOW, FAN_MEDIUM as FAN_MEDIUM, FAN_MIDDLE as FAN_MIDDLE, FAN_OFF as FAN_OFF, FAN_ON as FAN_ON, HVAC_MODE_AUTO as HVAC_MODE_AUTO, HVAC_MODE_COOL as HVAC_MODE_COOL, HVAC_MODE_DRY as HVAC_MODE_DRY, HVAC_MODE_FAN_ONLY as HVAC_MODE_FAN_ONLY, HVAC_MODE_HEAT as HVAC_MODE_HEAT, HVAC_MODE_HEAT_COOL as HVAC_MODE_HEAT_COOL, HVAC_MODE_OFF as HVAC_MODE_OFF, PRESET_ACTIVITY as PRESET_ACTIVITY, PRESET_AWAY as PRESET_AWAY, PRESET_BOOST as PRESET_BOOST, PRESET_COMFORT as PRESET_COMFORT, PRESET_ECO as PRESET_ECO, PRESET_HOME as PRESET_HOME, PRESET_NONE as PRESET_NONE, PRESET_SLEEP as PRESET_SLEEP, SUPPORT_FAN_MODE as SUPPORT_FAN_MODE, SUPPORT_PRESET_MODE as SUPPORT_PRESET_MODE, SUPPORT_SWING_MODE as SUPPORT_SWING_MODE, SUPPORT_TARGET_TEMPERATURE as SUPPORT_TARGET_TEMPERATURE, SUPPORT_TARGET_TEMPERATURE_RANGE as SUPPORT_TARGET_TEMPERATURE_RANGE, SWING_BOTH as SWING_BOTH, SWING_HORIZONTAL as SWING_HORIZONTAL, SWING_OFF as SWING_OFF, SWING_VERTICAL as SWING_VERTICAL
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_TEMPERATURE as ATTR_TEMPERATURE, PRECISION_HALVES as PRECISION_HALVES, PRECISION_TENTHS as PRECISION_TENTHS, PRECISION_WHOLE as PRECISION_WHOLE, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

_CLIMATE_MODES: EsphomeEnumMapper[ClimateMode, str]
_CLIMATE_ACTIONS: EsphomeEnumMapper[ClimateAction, str]
_FAN_MODES: EsphomeEnumMapper[ClimateFanMode, str]
_SWING_MODES: EsphomeEnumMapper[ClimateSwingMode, str]
_PRESETS: EsphomeEnumMapper[ClimatePreset, str]

class EsphomeClimateEntity(EsphomeEntity[ClimateInfo, ClimateState], ClimateEntity):
    @property
    def precision(self) -> float: ...
    @property
    def temperature_unit(self) -> str: ...
    @property
    def hvac_modes(self) -> list[str]: ...
    @property
    def fan_modes(self) -> list[str]: ...
    @property
    def preset_modes(self) -> list[str]: ...
    @property
    def swing_modes(self) -> list[str]: ...
    @property
    def target_temperature_step(self) -> float: ...
    @property
    def min_temp(self) -> float: ...
    @property
    def max_temp(self) -> float: ...
    @property
    def supported_features(self) -> int: ...
    def hvac_mode(self) -> Union[str, None]: ...
    def hvac_action(self) -> Union[str, None]: ...
    def fan_mode(self) -> Union[str, None]: ...
    def preset_mode(self) -> Union[str, None]: ...
    def swing_mode(self) -> Union[str, None]: ...
    def current_temperature(self) -> Union[float, None]: ...
    def target_temperature(self) -> Union[float, None]: ...
    def target_temperature_low(self) -> Union[float, None]: ...
    def target_temperature_high(self) -> Union[float, None]: ...
    async def async_set_temperature(self, **kwargs: Union[float, str]) -> None: ...
    async def async_set_hvac_mode(self, hvac_mode: str) -> None: ...
    async def async_set_preset_mode(self, preset_mode: str) -> None: ...
    async def async_set_fan_mode(self, fan_mode: str) -> None: ...
    async def async_set_swing_mode(self, swing_mode: str) -> None: ...



import logging
from .const import DATA_SDM as DATA_SDM, DOMAIN as DOMAIN, SDM_SCOPES as SDM_SCOPES
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import config_entry_oauth2_flow as config_entry_oauth2_flow
from homeassistant.util.json import load_json as load_json
from typing import Any

DATA_FLOW_IMPL: str
_LOGGER: Any

def register_flow_implementation(hass: HomeAssistant, domain: str, name: str, gen_authorize_url: str, convert_code: str) -> None: ...

class NestAuthError(HomeAssistantError): ...
class CodeInvalid(NestAuthError): ...
class UnexpectedStateError(HomeAssistantError): ...

class NestFlowHandler(config_entry_oauth2_flow.AbstractOAuth2FlowHandler):
    DOMAIN: Any
    VERSION: int
    _reauth: bool
    def __init__(self) -> None: ...
    @classmethod
    def register_sdm_api(cls, hass: HomeAssistant) -> None: ...
    def is_sdm_api(self) -> bool: ...
    @property
    def logger(self) -> logging.Logger: ...
    @property
    def extra_authorize_data(self) -> dict[str, str]: ...
    async def async_oauth_create_entry(self, data: dict[str, Any]) -> FlowResult: ...
    async def async_step_reauth(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_reauth_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    flow_impl: Any
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_link(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_import(self, info: dict[str, Any]) -> FlowResult: ...
    def _entry_from_tokens(self, title: str, flow: dict[str, Any], tokens: Union[list[Any], dict[Any, Any]]) -> FlowResult: ...



from .const import DOMAIN as DOMAIN
from .subscriber import Subscriber as Subscriber
from devolo_home_control_api.devices.zwave import Zwave as Zwave
from devolo_home_control_api.homecontrol import HomeControl as HomeControl
from homeassistant.helpers.entity import Entity as Entity
from typing import Any

_LOGGER: Any

class DevoloDeviceEntity(Entity):
    _device_instance: Any
    _homecontrol: Any
    _attr_available: Any
    _attr_name: Any
    _attr_should_poll: bool
    _attr_unique_id: Any
    _attr_device_info: Any
    subscriber: Any
    sync_callback: Any
    _value: Any
    _unit: str
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    def _sync(self, message: tuple) -> None: ...
    def _generic_message(self, message: tuple) -> None: ...



from . import NotionEntity as NotionEntity
from .const import DATA_COORDINATOR as DATA_COORDINATOR, DOMAIN as DOMAIN, LOGGER as LOGGER, SENSOR_BATTERY as SENSOR_BATTERY, SENSOR_DOOR as SENSOR_DOOR, SENSOR_GARAGE_DOOR as SENSOR_GARAGE_DOOR, SENSOR_LEAK as SENSOR_LEAK, SENSOR_MISSING as SENSOR_MISSING, SENSOR_SAFE as SENSOR_SAFE, SENSOR_SLIDING as SENSOR_SLIDING, SENSOR_SMOKE_CO as SENSOR_SMOKE_CO, SENSOR_WINDOW_HINGED_HORIZONTAL as SENSOR_WINDOW_HINGED_HORIZONTAL, SENSOR_WINDOW_HINGED_VERTICAL as SENSOR_WINDOW_HINGED_VERTICAL
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

BINARY_SENSOR_TYPES: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class NotionBinarySensor(NotionEntity, BinarySensorEntity):
    _attr_is_on: Any
    def _async_update_from_latest_data(self) -> None: ...



import asyncio
import voluptuous as vol
from . import service as service
from .device_registry import DeviceRegistry as DeviceRegistry
from .entity import Entity as Entity
from .entity_registry import DISABLED_INTEGRATION as DISABLED_INTEGRATION, EntityRegistry as EntityRegistry
from .event import async_call_later as async_call_later, async_track_time_interval as async_track_time_interval
from .typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from collections.abc import Coroutine, Iterable
from contextvars import ContextVar
from datetime import datetime, timedelta
from homeassistant import config_entries as config_entries
from homeassistant.const import ATTR_RESTORED as ATTR_RESTORED, DEVICE_DEFAULT_NAME as DEVICE_DEFAULT_NAME, EVENT_HOMEASSISTANT_STARTED as EVENT_HOMEASSISTANT_STARTED
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, CoreState as CoreState, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, callback as callback, split_entity_id as split_entity_id, valid_entity_id as valid_entity_id
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError, PlatformNotReady as PlatformNotReady, RequiredParameterMissing as RequiredParameterMissing
from homeassistant.setup import async_start_setup as async_start_setup
from homeassistant.util.async_ import run_callback_threadsafe as run_callback_threadsafe
from logging import Logger
from types import ModuleType
from typing import Any, Callable

SLOW_SETUP_WARNING: int
SLOW_SETUP_MAX_WAIT: int
SLOW_ADD_ENTITY_MAX_WAIT: int
SLOW_ADD_MIN_TIMEOUT: int
PLATFORM_NOT_READY_RETRIES: int
DATA_ENTITY_PLATFORM: str
PLATFORM_NOT_READY_BASE_WAIT_TIME: int
_LOGGER: Any

class AddEntitiesCallback:
    def __call__(self, new_entities: Iterable[Entity], update_before_add: bool = ...) -> None: ...

class EntityPlatform:
    hass: Any
    logger: Any
    domain: Any
    platform_name: Any
    platform: Any
    scan_interval: Any
    entity_namespace: Any
    config_entry: Any
    entities: Any
    _tasks: Any
    _setup_complete: bool
    _async_unsub_polling: Any
    _async_cancel_retry_setup: Any
    _process_updates: Any
    parallel_updates: Any
    parallel_updates_created: Any
    def __init__(self, hass: HomeAssistant, logger: Logger, domain: str, platform_name: str, platform: Union[ModuleType, None], scan_interval: timedelta, entity_namespace: Union[str, None]) -> None: ...
    def __repr__(self) -> str: ...
    def _get_parallel_updates_semaphore(self, entity_has_async_update: bool) -> Union[asyncio.Semaphore, None]: ...
    async def async_setup(self, platform_config: ConfigType, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
    async def async_shutdown(self) -> None: ...
    def async_cancel_retry_setup(self) -> None: ...
    async def async_setup_entry(self, config_entry: config_entries.ConfigEntry) -> bool: ...
    async def _async_setup_platform(self, async_create_setup_task: Callable[[], Coroutine], tries: int = ...) -> bool: ...
    def _schedule_add_entities(self, new_entities: Iterable[Entity], update_before_add: bool = ...) -> None: ...
    def _async_schedule_add_entities(self, new_entities: Iterable[Entity], update_before_add: bool = ...) -> None: ...
    def add_entities(self, new_entities: Iterable[Entity], update_before_add: bool = ...) -> None: ...
    async def async_add_entities(self, new_entities: Iterable[Entity], update_before_add: bool = ...) -> None: ...
    async def _async_add_entity(self, entity: Entity, update_before_add: bool, entity_registry: EntityRegistry, device_registry: DeviceRegistry) -> None: ...
    async def async_reset(self) -> None: ...
    def async_unsub_polling(self) -> None: ...
    async def async_destroy(self) -> None: ...
    async def async_remove_entity(self, entity_id: str) -> None: ...
    async def async_extract_from_service(self, service_call: ServiceCall, expand_group: bool = ...) -> list[Entity]: ...
    def async_register_entity_service(self, name: str, schema: Union[dict, vol.Schema], func: Union[str, Callable[..., Any]], required_features: Union[Iterable[int], None] = ...) -> None: ...
    async def _update_entity_states(self, now: datetime) -> None: ...

current_platform: ContextVar[Union[EntityPlatform, None]]

def async_get_current_platform() -> EntityPlatform: ...
def async_get_platforms(hass: HomeAssistant, integration_name: str) -> list[EntityPlatform]: ...



from .connection import ActiveConnection as ActiveConnection
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.json import JSONEncoder as JSONEncoder
from typing import Any, Final

WebSocketCommandHandler: Any
AsyncWebSocketCommandHandler: Any
DOMAIN: Final[str]
URL: Final[str]
PENDING_MSG_PEAK: Final[int]
PENDING_MSG_PEAK_TIME: Final[int]
MAX_PENDING_MSG: Final[int]
ERR_ID_REUSE: Final[str]
ERR_INVALID_FORMAT: Final[str]
ERR_NOT_FOUND: Final[str]
ERR_NOT_SUPPORTED: Final[str]
ERR_HOME_ASSISTANT_ERROR: Final[str]
ERR_UNKNOWN_COMMAND: Final[str]
ERR_UNKNOWN_ERROR: Final[str]
ERR_UNAUTHORIZED: Final[str]
ERR_TIMEOUT: Final[str]
ERR_TEMPLATE_ERROR: Final[str]
TYPE_RESULT: Final[str]
CANCELLATION_ERRORS: Final[Any]
SIGNAL_WEBSOCKET_CONNECTED: Final[str]
SIGNAL_WEBSOCKET_DISCONNECTED: Final[str]
DATA_CONNECTIONS: Final[Any]
JSON_DUMP: Final[Any]



from .common import FritzBoxTools as FritzBoxTools, FritzData as FritzData, FritzDevice as FritzDevice, FritzDeviceBase as FritzDeviceBase
from .const import DATA_FRITZ as DATA_FRITZ, DOMAIN as DOMAIN
from homeassistant.components.device_tracker import SOURCE_TYPE_ROUTER as SOURCE_TYPE_ROUTER
from homeassistant.components.device_tracker.config_entry import ScannerEntity as ScannerEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_IMPORT as SOURCE_IMPORT
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

_LOGGER: Any
YAML_DEFAULT_HOST: str
YAML_DEFAULT_USERNAME: str
PLATFORM_SCHEMA: Any

async def async_get_scanner(hass: HomeAssistant, config: ConfigType) -> None: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...
def _async_add_entities(router: FritzBoxTools, async_add_entities: AddEntitiesCallback, data_fritz: FritzData) -> None: ...

class FritzBoxTracker(FritzDeviceBase, ScannerEntity):
    _last_activity: Any
    _active: bool
    def __init__(self, router: FritzBoxTools, device: FritzDevice) -> None: ...
    @property
    def is_connected(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def icon(self) -> str: ...
    @property
    def extra_state_attributes(self) -> dict[str, str]: ...
    @property
    def source_type(self) -> str: ...
    async def async_process_update(self) -> None: ...



from .const import ATTR_SDS011 as ATTR_SDS011, ATTR_SPS30 as ATTR_SPS30, DEFAULT_NAME as DEFAULT_NAME, DEFAULT_UPDATE_INTERVAL as DEFAULT_UPDATE_INTERVAL, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER
from aiohttp import ClientSession as ClientSession
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_HOST as CONF_HOST
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.device_registry import CONNECTION_NETWORK_MAC as CONNECTION_NETWORK_MAC
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from nettigo_air_monitor import NAMSensors as NAMSensors
from typing import Any

_LOGGER: Any
PLATFORMS: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class NAMDataUpdateCoordinator(DataUpdateCoordinator):
    host: Any
    nam: Any
    _unique_id: Any
    def __init__(self, hass: HomeAssistant, session: ClientSession, host: str, unique_id: Union[str, None]) -> None: ...
    async def _async_update_data(self) -> NAMSensors: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def device_info(self) -> DeviceInfo: ...



from .const import DATA_ELGATO_CLIENT as DATA_ELGATO_CLIENT, DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from typing import Any

PLATFORMS: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...



from .const import CLIENTID_PREFIX as CLIENTID_PREFIX, CONF_IGNORED_SOURCES as CONF_IGNORED_SOURCES, DOMAIN as DOMAIN, NICKNAME as NICKNAME
from collections.abc import Iterable
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_MAC as CONF_MAC, CONF_PIN as CONF_PIN
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.debounce import Debouncer as Debouncer
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from typing import Any, Final

_LOGGER: Any
PLATFORMS: Final[list[str]]
SCAN_INTERVAL: Final[Any]

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...
async def update_listener(hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...

class BraviaTVCoordinator(DataUpdateCoordinator[None]):
    braviarc: Any
    pin: Any
    ignored_sources: Any
    muted: bool
    channel_name: Any
    media_title: Any
    source: Any
    source_list: Any
    original_content_list: Any
    content_mapping: Any
    duration: Any
    content_uri: Any
    program_media_type: Any
    audio_output: Any
    min_volume: Any
    max_volume: Any
    volume_level: Any
    is_on: bool
    playing: bool
    state_lock: Any
    def __init__(self, hass: HomeAssistant, host: str, mac: str, pin: str, ignored_sources: list[str]) -> None: ...
    def _send_command(self, command: str, repeats: int = ...) -> None: ...
    def _get_source(self) -> Union[str, None]: ...
    def _refresh_volume(self) -> bool: ...
    def _refresh_channels(self) -> bool: ...
    def _refresh_playing_info(self) -> None: ...
    def _update_tv_data(self) -> None: ...
    async def _async_update_data(self) -> None: ...
    async def async_turn_on(self) -> None: ...
    async def async_turn_off(self) -> None: ...
    async def async_set_volume_level(self, volume: float) -> None: ...
    async def async_volume_up(self) -> None: ...
    async def async_volume_down(self) -> None: ...
    async def async_volume_mute(self, mute: bool) -> None: ...
    async def async_media_play(self) -> None: ...
    async def async_media_pause(self) -> None: ...
    async def async_media_stop(self) -> None: ...
    async def async_media_next_track(self) -> None: ...
    async def async_media_previous_track(self) -> None: ...
    async def async_select_source(self, source: str) -> None: ...
    async def async_send_command(self, command: Iterable[str], repeats: int) -> None: ...



from homeassistant import core as core
from homeassistant.config import get_default_config_dir as get_default_config_dir
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.check_config import async_check_ha_config_file as async_check_ha_config_file
from homeassistant.util.yaml import Secrets as Secrets
from typing import Any, Callable

REQUIREMENTS: Any
_LOGGER: Any
MOCKS: dict[str, tuple[str, Callable]]
PATCHES: dict[str, Any]
C_HEAD: str
ERROR_STR: str

def color(the_color, *args, reset: Any | None = ...): ...
def run(script_args: list) -> int: ...
def check(config_dir, secrets: bool = ...): ...
async def async_check_config(config_dir): ...
def line_info(obj, **kwargs): ...
def dump_dict(layer, indent_count: int = ..., listi: bool = ..., **kwargs): ...



from . import LcnEntity as LcnEntity
from .const import BINSENSOR_PORTS as BINSENSOR_PORTS, CONF_DOMAIN_DATA as CONF_DOMAIN_DATA, SETPOINTS as SETPOINTS
from .helpers import DeviceConnectionType as DeviceConnectionType, InputType as InputType, get_device_connection as get_device_connection
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITIES as CONF_ENTITIES, CONF_SOURCE as CONF_SOURCE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

def create_lcn_binary_sensor_entity(hass: HomeAssistant, entity_config: ConfigType, config_entry: ConfigEntry) -> LcnEntity: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class LcnRegulatorLockSensor(LcnEntity, BinarySensorEntity):
    setpoint_variable: Any
    _value: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...
    def input_received(self, input_obj: InputType) -> None: ...

class LcnBinarySensor(LcnEntity, BinarySensorEntity):
    bin_sensor_port: Any
    _value: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...
    def input_received(self, input_obj: InputType) -> None: ...

class LcnLockKeysSensor(LcnEntity, BinarySensorEntity):
    source: Any
    _value: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...
    def input_received(self, input_obj: InputType) -> None: ...



from . import entity_registry as entity_registry
from .debounce import Debouncer as Debouncer
from .typing import UNDEFINED as UNDEFINED, UndefinedType as UndefinedType
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import EVENT_HOMEASSISTANT_STARTED as EVENT_HOMEASSISTANT_STARTED
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import RequiredParameterMissing as RequiredParameterMissing
from homeassistant.loader import bind_hass as bind_hass
from typing import Any, NamedTuple

_LOGGER: Any
DATA_REGISTRY: str
EVENT_DEVICE_REGISTRY_UPDATED: str
STORAGE_KEY: str
STORAGE_VERSION: int
SAVE_DELAY: int
CLEANUP_DELAY: int
CONNECTION_NETWORK_MAC: str
CONNECTION_UPNP: str
CONNECTION_ZIGBEE: str
DISABLED_CONFIG_ENTRY: str
DISABLED_INTEGRATION: str
DISABLED_USER: str
ORPHANED_DEVICE_KEEP_SECONDS: Any

class _DeviceIndex(NamedTuple):
    identifiers: dict[tuple[str, str], str]
    connections: dict[tuple[str, str], str]

class DeviceEntry:
    config_entries: set[str]
    connections: set[tuple[str, str]]
    identifiers: set[tuple[str, str]]
    manufacturer: Union[str, None]
    model: Union[str, None]
    name: Union[str, None]
    sw_version: Union[str, None]
    via_device_id: Union[str, None]
    area_id: Union[str, None]
    name_by_user: Union[str, None]
    entry_type: Union[str, None]
    id: str
    is_new: bool
    disabled_by: Union[str, None]
    suggested_area: Union[str, None]
    @property
    def disabled(self) -> bool: ...
    def __init__(self, config_entries, connections, identifiers, manufacturer, model, name, sw_version, via_device_id, area_id, name_by_user, entry_type, id, is_new, disabled_by, suggested_area) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class DeletedDeviceEntry:
    config_entries: set[str]
    connections: set[tuple[str, str]]
    identifiers: set[tuple[str, str]]
    id: str
    orphaned_timestamp: Union[float, None]
    def to_device_entry(self, config_entry_id: str, connections: set[tuple[str, str]], identifiers: set[tuple[str, str]]) -> DeviceEntry: ...
    def __init__(self, config_entries, connections, identifiers, id, orphaned_timestamp) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

def format_mac(mac: str) -> str: ...
def _async_get_device_id_from_index(devices_index: _DeviceIndex, identifiers: set[tuple[str, str]], connections: Union[set[tuple[str, str]], None]) -> Union[str, None]: ...

class DeviceRegistry:
    devices: dict[str, DeviceEntry]
    deleted_devices: dict[str, DeletedDeviceEntry]
    _registered_index: _DeviceIndex
    _deleted_index: _DeviceIndex
    hass: Any
    _store: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    def async_get(self, device_id: str) -> Union[DeviceEntry, None]: ...
    def async_get_device(self, identifiers: set[tuple[str, str]], connections: Union[set[tuple[str, str]], None] = ...) -> Union[DeviceEntry, None]: ...
    def _async_get_deleted_device(self, identifiers: set[tuple[str, str]], connections: Union[set[tuple[str, str]], None]) -> Union[DeletedDeviceEntry, None]: ...
    def _add_device(self, device: Union[DeviceEntry, DeletedDeviceEntry]) -> None: ...
    def _remove_device(self, device: Union[DeviceEntry, DeletedDeviceEntry]) -> None: ...
    def _update_device(self, old_device: DeviceEntry, new_device: DeviceEntry) -> None: ...
    def _clear_index(self) -> None: ...
    def _rebuild_index(self) -> None: ...
    def async_get_or_create(self, config_entry_id: str, *, connections: Union[set[tuple[str, str]], None] = ..., identifiers: Union[set[tuple[str, str]], None] = ..., manufacturer: Union[str, None, UndefinedType] = ..., model: Union[str, None, UndefinedType] = ..., name: Union[str, None, UndefinedType] = ..., default_manufacturer: Union[str, None, UndefinedType] = ..., default_model: Union[str, None, UndefinedType] = ..., default_name: Union[str, None, UndefinedType] = ..., sw_version: Union[str, None, UndefinedType] = ..., entry_type: Union[str, None, UndefinedType] = ..., via_device: Union[tuple[str, str], None] = ..., disabled_by: Union[str, None, UndefinedType] = ..., suggested_area: Union[str, None, UndefinedType] = ...) -> DeviceEntry: ...
    def async_update_device(self, device_id: str, *, area_id: Union[str, None, UndefinedType] = ..., manufacturer: Union[str, None, UndefinedType] = ..., model: Union[str, None, UndefinedType] = ..., name: Union[str, None, UndefinedType] = ..., name_by_user: Union[str, None, UndefinedType] = ..., new_identifiers: Union[set[tuple[str, str]], UndefinedType] = ..., sw_version: Union[str, None, UndefinedType] = ..., via_device_id: Union[str, None, UndefinedType] = ..., remove_config_entry_id: Union[str, UndefinedType] = ..., disabled_by: Union[str, None, UndefinedType] = ..., suggested_area: Union[str, None, UndefinedType] = ...) -> Union[DeviceEntry, None]: ...
    def _async_update_device(self, device_id: str, *, add_config_entry_id: Union[str, UndefinedType] = ..., remove_config_entry_id: Union[str, UndefinedType] = ..., merge_connections: Union[set[tuple[str, str]], UndefinedType] = ..., merge_identifiers: Union[set[tuple[str, str]], UndefinedType] = ..., new_identifiers: Union[set[tuple[str, str]], UndefinedType] = ..., manufacturer: Union[str, None, UndefinedType] = ..., model: Union[str, None, UndefinedType] = ..., name: Union[str, None, UndefinedType] = ..., sw_version: Union[str, None, UndefinedType] = ..., entry_type: Union[str, None, UndefinedType] = ..., via_device_id: Union[str, None, UndefinedType] = ..., area_id: Union[str, None, UndefinedType] = ..., name_by_user: Union[str, None, UndefinedType] = ..., disabled_by: Union[str, None, UndefinedType] = ..., suggested_area: Union[str, None, UndefinedType] = ...) -> Union[DeviceEntry, None]: ...
    def async_remove_device(self, device_id: str) -> None: ...
    async def async_load(self) -> None: ...
    def async_schedule_save(self) -> None: ...
    def _data_to_save(self) -> dict[str, list[dict[str, Any]]]: ...
    def async_clear_config_entry(self, config_entry_id: str) -> None: ...
    def async_purge_expired_orphaned_devices(self) -> None: ...
    def async_clear_area_id(self, area_id: str) -> None: ...

def async_get(hass: HomeAssistant) -> DeviceRegistry: ...
async def async_load(hass: HomeAssistant) -> None: ...
async def async_get_registry(hass: HomeAssistant) -> DeviceRegistry: ...
def async_entries_for_area(registry: DeviceRegistry, area_id: str) -> list[DeviceEntry]: ...
def async_entries_for_config_entry(registry: DeviceRegistry, config_entry_id: str) -> list[DeviceEntry]: ...
def async_config_entry_disabled_by_changed(registry: DeviceRegistry, config_entry: ConfigEntry) -> None: ...
def async_cleanup(hass: HomeAssistant, dev_reg: DeviceRegistry, ent_reg: entity_registry.EntityRegistry) -> None: ...
def async_setup_cleanup(hass: HomeAssistant, dev_reg: DeviceRegistry) -> None: ...
def _normalize_connections(connections: set[tuple[str, str]]) -> set[tuple[str, str]]: ...
def _add_device_to_index(devices_index: _DeviceIndex, device: Union[DeviceEntry, DeletedDeviceEntry]) -> None: ...
def _remove_device_from_index(devices_index: _DeviceIndex, device: Union[DeviceEntry, DeletedDeviceEntry]) -> None: ...



import abc
import asyncio
import voluptuous as vol
from .core import HomeAssistant as HomeAssistant, callback as callback
from .exceptions import HomeAssistantError as HomeAssistantError
from collections.abc import Mapping
from typing import Any, TypedDict

RESULT_TYPE_FORM: str
RESULT_TYPE_CREATE_ENTRY: str
RESULT_TYPE_ABORT: str
RESULT_TYPE_EXTERNAL_STEP: str
RESULT_TYPE_EXTERNAL_STEP_DONE: str
RESULT_TYPE_SHOW_PROGRESS: str
RESULT_TYPE_SHOW_PROGRESS_DONE: str
EVENT_DATA_ENTRY_FLOW_PROGRESSED: str

class FlowError(HomeAssistantError): ...
class UnknownHandler(FlowError): ...
class UnknownFlow(FlowError): ...
class UnknownStep(FlowError): ...

class AbortFlow(FlowError):
    reason: Any
    description_placeholders: Any
    def __init__(self, reason: str, description_placeholders: Union[dict, None] = ...) -> None: ...

class FlowResult(TypedDict):
    version: int
    type: str
    flow_id: str
    handler: str
    title: str
    data: Mapping[str, Any]
    step_id: str
    data_schema: vol.Schema
    extra: str
    required: bool
    errors: Union[dict[str, str], None]
    description: Union[str, None]
    description_placeholders: Union[dict[str, Any], None]
    progress_action: str
    url: str
    reason: str
    context: dict[str, Any]
    result: Any
    last_step: Union[bool, None]
    options: Mapping[str, Any]

class FlowManager(abc.ABC, metaclass=abc.ABCMeta):
    hass: Any
    _initializing: Any
    _initialize_tasks: Any
    _progress: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_wait_init_flow_finish(self, handler: str) -> None: ...
    @abc.abstractmethod
    async def async_create_flow(self, handler_key: Any, *, context: Union[dict[str, Any], None] = ..., data: Union[dict[str, Any], None] = ...) -> FlowHandler: ...
    @abc.abstractmethod
    async def async_finish_flow(self, flow: FlowHandler, result: FlowResult) -> FlowResult: ...
    async def async_post_init(self, flow: FlowHandler, result: FlowResult) -> None: ...
    def async_progress(self, include_uninitialized: bool = ...) -> list[FlowResult]: ...
    async def async_init(self, handler: str, *, context: Union[dict[str, Any], None] = ..., data: Any = ...) -> FlowResult: ...
    async def _async_init(self, init_done: asyncio.Future, handler: str, context: dict, data: Any) -> tuple[FlowHandler, FlowResult]: ...
    async def async_shutdown(self) -> None: ...
    async def async_configure(self, flow_id: str, user_input: Union[dict, None] = ...) -> FlowResult: ...
    def async_abort(self, flow_id: str) -> None: ...
    async def _async_handle_step(self, flow: Any, step_id: str, user_input: Union[dict, None], step_done: Union[asyncio.Future, None] = ...) -> FlowResult: ...

class FlowHandler:
    cur_step: Union[dict[str, str], None]
    flow_id: str
    hass: HomeAssistant
    handler: str
    context: dict[str, Any]
    init_step: str
    VERSION: int
    @property
    def source(self) -> Union[str, None]: ...
    @property
    def show_advanced_options(self) -> bool: ...
    def async_show_form(self, step_id: str, *, data_schema: vol.Schema = ..., errors: Union[dict[str, str], None] = ..., description_placeholders: Union[dict[str, Any], None] = ..., last_step: Union[bool, None] = ...) -> FlowResult: ...
    def async_create_entry(self, title: str, data: Mapping[str, Any], *, description: Union[str, None] = ..., description_placeholders: Union[dict, None] = ...) -> FlowResult: ...
    def async_abort(self, reason: str, *, description_placeholders: Union[dict, None] = ...) -> FlowResult: ...
    def async_external_step(self, step_id: str, url: str, *, description_placeholders: Union[dict, None] = ...) -> FlowResult: ...
    def async_external_step_done(self, next_step_id: str) -> FlowResult: ...
    def async_show_progress(self, step_id: str, progress_action: str, *, description_placeholders: Union[dict, None] = ...) -> FlowResult: ...
    def async_show_progress_done(self, next_step_id: str) -> FlowResult: ...

def _create_abort_data(flow_id: str, handler: str, reason: str, description_placeholders: Union[dict, None] = ...) -> FlowResult: ...



from homeassistant.helpers import device_registry as dev_reg, entity_registry as ent_reg

class PermissionLookup:
    entity_registry: ent_reg.EntityRegistry
    device_registry: dev_reg.DeviceRegistry
    def __init__(self, entity_registry, device_registry) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...



from . import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_BATTERY_CHARGING as DEVICE_CLASS_BATTERY_CHARGING, DEVICE_CLASS_COLD as DEVICE_CLASS_COLD, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_GARAGE_DOOR as DEVICE_CLASS_GARAGE_DOOR, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_HEAT as DEVICE_CLASS_HEAT, DEVICE_CLASS_LIGHT as DEVICE_CLASS_LIGHT, DEVICE_CLASS_LOCK as DEVICE_CLASS_LOCK, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_MOVING as DEVICE_CLASS_MOVING, DEVICE_CLASS_OCCUPANCY as DEVICE_CLASS_OCCUPANCY, DEVICE_CLASS_OPENING as DEVICE_CLASS_OPENING, DEVICE_CLASS_PLUG as DEVICE_CLASS_PLUG, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_PRESENCE as DEVICE_CLASS_PRESENCE, DEVICE_CLASS_PROBLEM as DEVICE_CLASS_PROBLEM, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND, DEVICE_CLASS_VIBRATION as DEVICE_CLASS_VIBRATION, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW, DOMAIN as DOMAIN
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.device_automation.const import CONF_TURNED_OFF as CONF_TURNED_OFF, CONF_TURNED_ON as CONF_TURNED_ON
from homeassistant.const import CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_TYPE as CONF_TYPE
from homeassistant.helpers.entity import get_device_class as get_device_class
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device
from typing import Any

DEVICE_CLASS_NONE: str
CONF_BAT_LOW: str
CONF_NOT_BAT_LOW: str
CONF_CHARGING: str
CONF_NOT_CHARGING: str
CONF_COLD: str
CONF_NOT_COLD: str
CONF_CONNECTED: str
CONF_NOT_CONNECTED: str
CONF_GAS: str
CONF_NO_GAS: str
CONF_HOT: str
CONF_NOT_HOT: str
CONF_LIGHT: str
CONF_NO_LIGHT: str
CONF_LOCKED: str
CONF_NOT_LOCKED: str
CONF_MOIST: str
CONF_NOT_MOIST: str
CONF_MOTION: str
CONF_NO_MOTION: str
CONF_MOVING: str
CONF_NOT_MOVING: str
CONF_OCCUPIED: str
CONF_NOT_OCCUPIED: str
CONF_PLUGGED_IN: str
CONF_NOT_PLUGGED_IN: str
CONF_POWERED: str
CONF_NOT_POWERED: str
CONF_PRESENT: str
CONF_NOT_PRESENT: str
CONF_PROBLEM: str
CONF_NO_PROBLEM: str
CONF_UNSAFE: str
CONF_NOT_UNSAFE: str
CONF_SMOKE: str
CONF_NO_SMOKE: str
CONF_SOUND: str
CONF_NO_SOUND: str
CONF_VIBRATION: str
CONF_NO_VIBRATION: str
CONF_OPENED: str
CONF_NOT_OPENED: str
TURNED_ON: Any
TURNED_OFF: Any
ENTITY_TRIGGERS: Any
TRIGGER_SCHEMA: Any

async def async_attach_trigger(hass, config, action, automation_info): ...
async def async_get_triggers(hass, device_id): ...
async def async_get_trigger_capabilities(hass, config): ...



from collections.abc import Awaitable
from homeassistant.core import HassJob as HassJob, HomeAssistant as HomeAssistant, callback as callback
from logging import Logger
from typing import Any, Callable

class Debouncer:
    hass: Any
    logger: Any
    _function: Any
    cooldown: Any
    immediate: Any
    _timer_task: Any
    _execute_at_end_of_timer: bool
    _execute_lock: Any
    _job: Any
    def __init__(self, hass: HomeAssistant, logger: Logger, cooldown: float, immediate: bool, *, function: Union[Callable[..., Awaitable[Any]], None] = ...) -> None: ...
    @property
    def function(self) -> Union[Callable[..., Awaitable[Any]], None]: ...
    @function.setter
    def function(self, function: Callable[..., Awaitable[Any]]) -> None: ...
    async def async_call(self) -> None: ...
    async def _handle_timer_finish(self) -> None: ...
    def async_cancel(self) -> None: ...
    def _schedule_timer(self) -> None: ...



from homeassistant.const import PERCENTAGE as PERCENTAGE
from typing import Any

DOMAIN: str
CONF_LOCATION: str
CONF_STATISTICS_ONLY: str
DEFAULT_LOCATION: str
DEFAULT_METHOD: str
DEFAULT_NAME: str
DEFAULT_SSL: bool
DEFAULT_VERIFY_SSL: bool
DEFAULT_STATISTICS_ONLY: bool
SERVICE_DISABLE: str
SERVICE_DISABLE_ATTR_DURATION: str
ATTR_BLOCKED_DOMAINS: str
MIN_TIME_BETWEEN_UPDATES: Any
DATA_KEY_API: str
DATA_KEY_COORDINATOR: str
SENSOR_DICT: Any
SENSOR_LIST: Any



from .const import DOMAIN as DOMAIN, LOGGER as LOGGER
from homeassistant.components import blueprint as blueprint
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.singleton import singleton as singleton

DATA_BLUEPRINTS: str

def async_get_blueprints(hass: HomeAssistant) -> blueprint.DomainBlueprints: ...
